@@ -1,21 +1,20 @@
 /*
- * Copyright (C) 2009 - 2010 Vivien Malerba <malerba@gnome-db.org>
- * Copyright (C) 2010 David King <davidk@openismus.com>
+ * Copyright (C) 2003 - 2011 Vivien Malerba <malerba@gnome-db.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * This Library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Library General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA  02110-1301, USA.
+ * You should have received a copy of the GNU Library General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * USA
  */
 
 #include <gdk/gdkkeysyms.h>
@@ -24,9 +23,7 @@
 #include <libgda/gda-data-handler.h>
 #include <libgda-ui/internal/utility.h>
 #include <glib/gi18n-lib.h>
-#if GTK_CHECK_VERSION (2,20,0)
 #include "widget-embedder.h"
-#endif
 static void gdaui_entry_shell_class_init (GdauiEntryShellClass *class);
 static void gdaui_entry_shell_init (GdauiEntryShell *wid);
 static void gdaui_entry_shell_dispose (GObject *object);
@@ -58,7 +55,6 @@ struct  _GdauiEntryShellPriv {
         GtkWidget           *embedder;
 	GtkWidget           *hbox;
         GtkWidget           *button;
-        GtkStyle            *orig_style;
         GdaDataHandler      *data_handler;
 	gboolean             show_actions;
 
@@ -161,7 +157,6 @@ gdaui_entry_shell_init (GdauiEntryShell * shell)
 	/* Setting the initial layout */
 	gtk_viewport_set_shadow_type (GTK_VIEWPORT (shell), GTK_SHADOW_NONE);
 	gtk_container_set_border_width (GTK_CONTAINER (shell), 0);
-	shell->priv->orig_style = gtk_style_copy (gtk_widget_get_style (GTK_WIDGET (shell)));
 
 	/* hbox */
 	hbox = gtk_hbox_new (FALSE, 0);
@@ -170,11 +165,7 @@ gdaui_entry_shell_init (GdauiEntryShell * shell)
 	shell->priv->hbox = hbox;
 
 	/* vbox to insert the real widget to edit data */
-#if GTK_CHECK_VERSION (2,20,0)
 	shell->priv->embedder = widget_embedder_new ();
-#else
-	shell->priv->embedder = gtk_vbox_new (FALSE, 0);
-#endif
 	gtk_box_pack_start (GTK_BOX (hbox), shell->priv->embedder, TRUE, TRUE, 0);
 	gtk_widget_show (shell->priv->embedder);	
 
@@ -185,6 +176,7 @@ gdaui_entry_shell_init (GdauiEntryShell * shell)
 	gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, TRUE, 0);
 	shell->priv->button = button;
 	gtk_widget_show_all (button);
+	gtk_widget_set_size_request (button, 15, 15);
 
 	g_signal_connect (G_OBJECT (button), "event",
 			  G_CALLBACK (event_cb), shell);
@@ -306,11 +298,7 @@ gdaui_entry_shell_pack_entry (GdauiEntryShell *shell, GtkWidget *main_widget)
 {
 	g_return_if_fail (GDAUI_IS_ENTRY_SHELL (shell));
 	g_return_if_fail (main_widget && GTK_IS_WIDGET (main_widget));
-#if GTK_CHECK_VERSION (2,18,0)
 	gtk_container_add (GTK_CONTAINER (shell->priv->embedder), main_widget);
-#else
-	gtk_box_pack_start (GTK_BOX (shell->priv->embedder), main_widget, TRUE, TRUE, 0);
-#endif
 
 	/* signals */
 	g_signal_connect (G_OBJECT (shell), "contents-modified",
@@ -355,7 +343,7 @@ event_cb (G_GNUC_UNUSED GtkWidget *widget, GdkEvent *event, GdauiEntryShell *she
 		GtkWidget *menu;
 		GdkEventKey *kevent = (GdkEventKey *) event;
 
-		if (kevent->keyval == GDK_space) {
+		if (kevent->keyval == GDK_KEY_space) {
 			guint attributes;
 
 			attributes = gdaui_entry_shell_refresh_attributes (shell);
@@ -367,7 +355,7 @@ event_cb (G_GNUC_UNUSED GtkWidget *widget, GdkEvent *event, GdauiEntryShell *she
 			done = TRUE;
 		}
 		else {
-			if (kevent->keyval == GDK_Tab)
+			if (kevent->keyval == GDK_KEY_Tab)
 				done = FALSE;
 			else
 				done = TRUE;
@@ -391,16 +379,14 @@ gdaui_entry_shell_refresh_status_display (GdauiEntryShell *shell)
 {
 	static GdkColor **colors = NULL;
 	GdkColor *normal = NULL, *prelight = NULL;
-	GdkColor *orig_normal, *orig_prelight;
 
 	g_return_if_fail (GDAUI_IS_ENTRY_SHELL (shell));
 
-	orig_normal = & (shell->priv->orig_style->bg[GTK_STATE_NORMAL]);
-	orig_prelight = & (shell->priv->orig_style->bg[GTK_STATE_PRELIGHT]);
-
 	if (!colors)
 		colors = _gdaui_utility_entry_build_info_colors_array ();
 
+	gtk_widget_set_tooltip_text (shell->priv->button, NULL);
+
 	if (shell->priv->value_is_null) {
 		normal = colors[0];
 		prelight = colors[1];
@@ -419,11 +405,6 @@ gdaui_entry_shell_refresh_status_display (GdauiEntryShell *shell)
 		gtk_widget_set_tooltip_text (shell->priv->button, _("Value is invalid"));
 	}
 
-	if (!normal)
-		normal = orig_normal;
-	if (!prelight)
-		prelight = orig_prelight;
-
 	gtk_widget_modify_bg (shell->priv->button, GTK_STATE_NORMAL, normal);
 	gtk_widget_modify_bg (shell->priv->button, GTK_STATE_ACTIVE, normal);
 	gtk_widget_modify_bg (shell->priv->button, GTK_STATE_PRELIGHT, prelight);
@@ -460,7 +441,7 @@ gdaui_entry_shell_refresh (GdauiEntryShell *shell)
 
 /**
  * gdaui_entry_shell_set_unknown:
- * @shell: the #GdauiEntryShell widget to refresh
+ * @shell: the GdauiEntryShell widget to refresh
  * @unknown: set to %TRUE if @shell's contents is unavailable and should not be modified
  *
  * Defines if @shell's contents is in an undefined state (shows or hides @shell's contents)
@@ -470,35 +451,5 @@ gdaui_entry_shell_set_unknown (GdauiEntryShell *shell, gboolean unknown)
 {
 	g_return_if_fail (GDAUI_IS_ENTRY_SHELL (shell));
 
-#if GTK_CHECK_VERSION (2,20,0)
 	widget_embedder_set_valid ((WidgetEmbedder*) shell->priv->embedder, !unknown);
-#else
-	/*
-	if (unknown)
-		gtk_widget_hide (shell->priv->embedder);
-	else
-		gtk_widget_show (shell->priv->embedder);
-	*/
-#endif
-}
-
-/**
- * gdaui_entry_shell_set_ucolor:
- * @shell: a #GdauiEntryShell
- * @red: the red component of a color
- * @green: the green component of a color
- * @blue: the blue component of a color
- * @alpha: the alpha component of a color
- *
- * Defines the color to be used when @de displays an invalid value. Any value not
- * between 0. and 1. will result in the default hard coded values to be used (grayish).
- *
- * Since: 4.2.13
- */
-void
-gdaui_entry_shell_set_ucolor (GdauiEntryShell *shell, gdouble red, gdouble green,
-			      gdouble blue, gdouble alpha)
-{
-	g_return_if_fail (GDAUI_IS_ENTRY_SHELL (shell));
-	widget_embedder_set_ucolor ((WidgetEmbedder*) shell->priv->embedder, red, green, blue, alpha);
 }
