@@ -1,21 +1,20 @@
 /*
- * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
- * Copyright (C) 2010 David King <davidk@openismus.com>
+ * Copyright (C) 2003 - 2011 Vivien Malerba <malerba@gnome-db.org>
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
+ * modify it under the terms of the GNU Library General Public
  * License as published by the Free Software Foundation; either
  * version 2 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
+ * Library General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
+ * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA  02110-1301, USA.
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 #include <string.h>
@@ -143,54 +142,28 @@ _gdaui_utility_entry_build_info_colors_array (void)
 	/* Green color */
 	color = g_new0 (GdkColor, 1);
 	gdk_color_parse (GDAUI_COLOR_NORMAL_NULL, color);
-	if (!gdk_colormap_alloc_color (gtk_widget_get_default_colormap (), color, FALSE, TRUE)) {
-		g_free (color);
-		color = NULL;
-	}
 	colors[0] = color;
 	
 	color = g_new0 (GdkColor, 1);
 	gdk_color_parse (GDAUI_COLOR_PRELIGHT_NULL, color);
-	if (!gdk_colormap_alloc_color (gtk_widget_get_default_colormap (), color, FALSE, TRUE)) {
-		g_free (color);
-		color = NULL;
-	}
 	colors[1] = color;
 	
-	
 	/* Blue color */
 	color = g_new0 (GdkColor, 1);
 	gdk_color_parse (GDAUI_COLOR_NORMAL_DEFAULT, color);
-	if (!gdk_colormap_alloc_color (gtk_widget_get_default_colormap (), color, FALSE, TRUE)) {
-		g_free (color);
-		color = NULL;
-	}
 	colors[2] = color;
 	
 	color = g_new0 (GdkColor, 1);
 	gdk_color_parse (GDAUI_COLOR_PRELIGHT_DEFAULT, color);
-	if (!gdk_colormap_alloc_color (gtk_widget_get_default_colormap (), color, FALSE, TRUE)) {
-		g_free (color);
-		color = NULL;
-	}
 	colors[3] = color;
 	
-	
 	/* Red color */
 	color = g_new0 (GdkColor, 1);
 	gdk_color_parse (GDAUI_COLOR_NORMAL_INVALID, color);
-	if (!gdk_colormap_alloc_color (gtk_widget_get_default_colormap (), color, FALSE, TRUE)) {
-		g_free (color);
-		color = NULL;
-	}
 	colors[4] = color;
 	
 	color = g_new0 (GdkColor, 1);
 	gdk_color_parse (GDAUI_COLOR_PRELIGHT_INVALID, color);
-	if (!gdk_colormap_alloc_color (gtk_widget_get_default_colormap (), color, FALSE, TRUE)) {
-		g_free (color);
-		color = NULL;
-	}
 	colors[5] = color;
 
 	return colors;
@@ -240,7 +213,7 @@ _gdaui_utility_proxy_compute_attributes_for_group (GdauiSetGroup *group, GdauiDa
         for (list = group->group->nodes; list; list = list->next) {
 		col = g_slist_index (((GdaSet*)model_iter)->holders, GDA_SET_NODE (list->data)->holder);
                 gtk_tree_model_get (GTK_TREE_MODEL (store), tree_iter,
-                                    GDAUI_DATA_STORE_COL_TO_DELETE, &local_to_del,
+                                    DATA_STORE_COL_TO_DELETE, &local_to_del,
                                     offset + col, &localattr, -1);
 		if (list == group->group->nodes)
 			attributes = localattr;
@@ -275,11 +248,12 @@ _gdaui_utility_proxy_compute_values_for_group (GdauiSetGroup *group, GdauiDataSt
 					       GdaDataModelIter *model_iter, 
 					       GtkTreeIter *tree_iter, gboolean model_values)
 {
+	gint offset;
 	GList *retval = NULL;
-#ifdef PROXY_STORE_EXTRA_VALUES
 	GdaDataProxy *proxy;
+
 	proxy = gdaui_data_store_get_proxy (store);
-#endif
+	offset = gda_data_proxy_get_proxied_model_n_cols (proxy);
 	if (!model_values) {
 		GSList *list;
 		GValue *value;
@@ -293,17 +267,13 @@ _gdaui_utility_proxy_compute_values_for_group (GdauiSetGroup *group, GdauiDataSt
 		}
 	}
 	else {
-		gint col, i;
-#ifdef PROXY_STORE_EXTRA_VALUES
-		gint proxy_row;
-#endif
+		gint col, i, proxy_row;
 		GdauiSetSource *source;
 		const GValue *value;
 		gboolean slow_way = FALSE;
 		gboolean ret_null = FALSE;
-#ifdef PROXY_STORE_EXTRA_VALUES
+
 		proxy_row = gdaui_data_store_get_row_from_iter (store, tree_iter);
-#endif
 		source = group->source;
 		for (i = 0 ; (i < source->shown_n_cols)  && !ret_null; i++) {
 			col = source->shown_cols_index[i];
@@ -397,11 +367,11 @@ create_data_error_dialog (GdauiDataProxy *form, gboolean with_question, gboolean
 	if (can_discard) {
 		msg1 = _("Current modified data is invalid");
 		if (with_question)
-			msg2 =_("You may now choose to correct it, or to discard "
+			msg2 =_("You may now choose to correct it, or to discard\n"
 				"the modifications.\n\n"
-				"What do you want to do?");
+				"What do you wan to do?");
 		else
-			msg2 = _("please correct it and try again, or discard "
+			msg2 = _("please correct it and try again, or discard\n"
 				 "the modifications.");
 	}
 	else {
@@ -420,12 +390,35 @@ create_data_error_dialog (GdauiDataProxy *form, gboolean with_question, gboolean
 						  "<b>%s:</b>\n\n%s", msg1, msg2);
 
 	if (filled_error && filled_error->message) {
-		GtkWidget *label;
+		GtkWidget *exp, *sw, *view;
+		GtkTextBuffer *buffer;
+		GtkTextIter start, end;
+		GtkTextTag *tag;
+		
+		exp = gtk_expander_new (_("Error details"));
 
-		label = gtk_label_new (filled_error->message);
+		sw = gtk_scrolled_window_new (NULL, NULL);
+		gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw),
+						GTK_POLICY_AUTOMATIC,
+						GTK_POLICY_AUTOMATIC);
+
+		view = gtk_text_view_new ();
+		buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
+		gtk_text_buffer_set_text (buffer, filled_error->message, -1);
+						
+		/* Use a tag to change the color for just one part of the widget */
+		tag = gtk_text_buffer_create_tag (buffer, "monospace",
+						  "family", "monospace", NULL);
+		gtk_text_buffer_get_bounds (buffer, &start, &end);
+		gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
+		
+		gtk_container_add (GTK_CONTAINER (sw), view);
+		gtk_container_add (GTK_CONTAINER (exp), sw);
 		gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dlg))),
-				    label, TRUE, TRUE, 0);
-		gtk_widget_show (label);
+				    exp, TRUE, TRUE, 0);
+		gtk_widget_show_all (exp);
+
+		gtk_window_set_resizable (GTK_WINDOW (dlg), TRUE);
 	}
 
 	return dlg;
