@@ -1,31 +1,26 @@
 /*
- * Copyright (C) 2000 Reinhard Müller <reinhard@src.gnome.org>
- * Copyright (C) 2000 - 2004 Rodrigo Moya <rodrigo@gnome-db.org>
- * Copyright (C) 2001 - 2011 Vivien Malerba <malerba@gnome-db.org>
- * Copyright (C) 2002 Cleber Rodrigues <cleberrrjr@bol.com.br>
- * Copyright (C) 2002 - 2003 Gonzalo Paniagua Javier <gonzalo@ximian.com>
- * Copyright (C) 2003 Filip Van Raemdonck <mechanix@debian.org>
- * Copyright (C) 2004 - 2005 Alan Knowles <alank@src.gnome.org>
- * Copyright (C) 2004 Jos Mara Casanova Crespo <jmcasanova@igalia.com>
- * Copyright (C) 2005 - 2009 Bas Driessen <bas.driessen@xobas.com>
- * Copyright (C) 2006 - 2008 Murray Cumming <murrayc@murrayc.com>
- * Copyright (C) 2007 Leonardo Boshell <lb@kmc.com.co>
- * Copyright (C) 2010 David King <davidk@openismus.com>
+ * Copyright (C) 1998 - 2011 The GNOME Foundation.
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * AUTHORS:
+ *      Michael Lausch <michael@lausch.at>
+ *	Rodrigo Moya <rodrigo@gnome-db.org>
+ *	Bas Driessen <bas.driessen@xobas.com>
+ *      Vivien Malerba <malerba@gnome-db.org>
  *
- * This library is distributed in the hope that it will be useful,
+ * This Library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
+ *
+ * This Library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
+ * Library General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA  02110-1301, USA.
+ * You should have received a copy of the GNU Library General Public
+ * License along with this Library; see the file COPYING.LIB.  If not,
+ * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 #ifndef __GDA_CONNECTION_H__
@@ -67,6 +62,47 @@ typedef enum {
 
 #define GDA_CONNECTION_NONEXIST_DSN_ERROR GDA_CONNECTION_DSN_NOT_FOUND_ERROR
 
+/**
+ * SECTION:gda-connection
+ * @short_description: A connection to a database
+ * @title: GdaConnection
+ * @stability: Stable
+ *
+ * Each connection to a database is represented by a #GdaConnection object. A connection is created (and opened)
+ * using gda_connection_open_from_dsn() if a data source has been defined, or gda_connection_open_from_string()
+ * otherwise. It is not recommended to create a #GdaConnection object using g_object_new() as the results are
+ * unpredictable (some parts won't correctly be initialized).
+ *
+ * Use the connection object to execute statements, use transactions, get meta data information, ...
+ *
+ * If supported by the database provider being used, statements can be executed asynchronously instead of
+ * blocking the execution thread untill the execution of a statement is finished. Each database provider
+ * is free to implement this feature as it wishes (using the API or using threads). The steps involved to
+ * execute a statement are then:
+ * <itemizedlist>
+ *   <listitem><para>Request the statement execution using
+ *	<link linkend="gda-connection-async-statement-execute">gda_connection_async_statement_execute() which returns an
+ *	  execution ID to be used to identify a specific request</link></para></listitem>
+ *   <listitem><para>Do some useful things (that is why async. statements' excution are for)</para></listitem>
+ *   <listitem><para>Use one or more times 
+ *	<link linkend="gda-connection-async-fetch-result">gda_connection_async_fetch_result()</link> to see
+ *	if the execution is finished, using the request ID</para></listitem>
+ *   <listitem><para>Use <link linkend="gda-connection-async-cancel">gda_connection_async_cancel()</link> to cancel
+ * the execution of a statement</para></listitem>
+ * </itemizedlist>
+ *
+ * The #GdaConnection object implements its own locking mechanism so it is thread-safe. However ad some database
+ * providers rely on an API which does not support threads or supports it only partially, the connections
+ * opened using those providers will only be accessible from the thread which created them (any other thread will
+ * be blocked trying to access the connection, use the
+ * <link linkend="gda-lockable-try-lock">gda_lockable_try_lock()</link> method to check it the connection
+ * is usable from a thread).
+ *
+ * If a connection really needs to be accessed by several threads at once, then it is possible to pass the
+ * #GDA_CONNECTION_OPTIONS_THREAD_SAFE flag when opening it. This flag requests that the real connection
+ * be created and really accessed in a <emphasis>private</emphasis> sub thread.
+ */
+
 struct _GdaConnection {
 	GObject               object;
 	GdaConnectionPrivate *priv;
@@ -204,31 +240,6 @@ typedef enum {
 	GDA_CONNECTION_FEATURE_LAST
 } GdaConnectionFeature;
 
-
-/**
- * GdaConnectionSchema
- *
- * Deprecated: 4.2: This was a leftover from the pre 4.0 area
- */
-typedef enum {
-	GDA_CONNECTION_SCHEMA_AGGREGATES,
-	GDA_CONNECTION_SCHEMA_DATABASES,
-	GDA_CONNECTION_SCHEMA_FIELDS,
-	GDA_CONNECTION_SCHEMA_INDEXES,
-	GDA_CONNECTION_SCHEMA_LANGUAGES,
-	GDA_CONNECTION_SCHEMA_NAMESPACES,
-	GDA_CONNECTION_SCHEMA_PARENT_TABLES,
-	GDA_CONNECTION_SCHEMA_PROCEDURES,
-	GDA_CONNECTION_SCHEMA_SEQUENCES,
-	GDA_CONNECTION_SCHEMA_TABLES,
-	GDA_CONNECTION_SCHEMA_TRIGGERS,
-	GDA_CONNECTION_SCHEMA_TYPES,
-	GDA_CONNECTION_SCHEMA_USERS,
-	GDA_CONNECTION_SCHEMA_VIEWS,
-	GDA_CONNECTION_SCHEMA_CONSTRAINTS,
-	GDA_CONNECTION_SCHEMA_TABLE_CONTENTS
-} GdaConnectionSchema;
-
 /**
  * GdaConnectionMetaType:
  * @GDA_CONNECTION_META_NAMESPACES: lists the <link linkend="GdaConnectionMetaTypeGDA_CONNECTION_META_NAMESPACES">namespaces</link> (or schemas for PostgreSQL)
