@@ -1,29 +1,24 @@
 /*
- * Copyright (C) 2006 - 2008 Murray Cumming <murrayc@murrayc.com>
- * Copyright (C) 2006 - 2011 Vivien Malerba <malerba@gnome-db.org>
- * Copyright (C) 2007 Leonardo Boshell <lb@kmc.com.co>
- * Copyright (C) 2008 Armin Burgmeier <armin@openismus.com>
- * Copyright (C) 2008 Phil Longstaff <plongstaff@rogers.com>
- * Copyright (C) 2008 Przemysław Grzegorczyk <pgrzegorczyk@gmail.com>
- * Copyright (C) 2009 Bas Driessen <bas.driessen@xobas.com>
- * Copyright (C) 2010 David King <davidk@openismus.com>
- * Copyright (C) 2010 Jonh Wendell <jwendell@gnome.org>
- * Copyright (C) 2011 Daniel Espinosa <esodan@gmail.com>
+ * Copyright (C) 2006 - 2011 The GNOME Foundation.
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * AUTHORS:
+ *      Vivien Malerba <malerba@gnome-db.org>
+ *      Daniel Espinosa <esodan@gmail.com>
  *
- * This library is distributed in the hope that it will be useful,
+ * This Library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
+ *
+ * This Library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
+ * Library General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA  02110-1301, USA.
+ * You should have received a copy of the GNU Library General Public
+ * License along with this Library; see the file COPYING.LIB.  If not,
+ * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 #include <stdlib.h>
@@ -1492,8 +1487,7 @@ gda_server_operation_load_data_from_xml (GdaServerOperation *op, xmlNodePtr node
 
 	/* actual data loading */
 	if (strcmp ((gchar*)node->name, "serv_op_data")) {
-		g_set_error (error, GDA_SERVER_OPERATION_ERROR,
-			     GDA_SERVER_OPERATION_XML_ERROR,
+		g_set_error (error, 0, 0,
 			     _("Expected tag <%s>, got <%s>"), "serv_op_data", node->name);
 		return FALSE;
 	}
@@ -1507,8 +1501,7 @@ gda_server_operation_load_data_from_xml (GdaServerOperation *op, xmlNodePtr node
 		}
 
 		if (strcmp ((gchar*)cur->name, "op_data")) {
-			g_set_error (error, GDA_SERVER_OPERATION_ERROR,
-				     GDA_SERVER_OPERATION_XML_ERROR,
+			g_set_error (error, 0, 0,
 				     _("Expected tag <%s>, got <%s>"), "op_data", cur->name);
 			return FALSE;
 		}
@@ -1539,10 +1532,7 @@ gda_server_operation_load_data_from_xml (GdaServerOperation *op, xmlNodePtr node
 				switch (opnode->type) {
 				case GDA_SERVER_OPERATION_NODE_PARAMLIST:
 					if (!extension) {
-						g_set_error (error,
-							     GDA_SERVER_OPERATION_ERROR,
-							     GDA_SERVER_OPERATION_XML_ERROR,
-							     "%s", 
+						g_set_error (error, 0, 0, "%s", 
 							     _("Parameterlist values can only be set for individual parameters within it"));
 						allok = FALSE;
 					}
@@ -1599,9 +1589,8 @@ gda_server_operation_load_data_from_xml (GdaServerOperation *op, xmlNodePtr node
 				return FALSE;
 		}
 		else {
-			g_set_error (error, GDA_SERVER_OPERATION_ERROR,
-				     GDA_SERVER_OPERATION_XML_ERROR,
-				     "%s", _("Missing attribute named 'path'"));
+			g_set_error (error, 0, 0, "%s", 
+				     _("Missing attribute named 'path'"));
 			return FALSE;
 		}
 		
@@ -2091,8 +2080,8 @@ gda_server_operation_get_value_at (GdaServerOperation *op, const gchar *path_for
 /**
  * gda_server_operation_get_sql_identifier_at: (skip)
  * @op: a #GdaServerOperation object
- * @cnc: (allow-none): a #GdaConnection, or %NULL
- * @prov: (allow-none): a #GdaServerProvider, or %NULL
+ * @cnc: a #GdaConnection, or %NULL
+ * @prov: a #GdaServerProvider, or %NULL
  * @path_format: a complete path to a node (starting with "/")
  * @...: arguments to use with @path_format to make a complete path
  *
@@ -2130,8 +2119,8 @@ gda_server_operation_get_sql_identifier_at (GdaServerOperation *op, GdaConnectio
 /**
  * gda_server_operation_get_sql_identifier_at_path:
  * @op: a #GdaServerOperation object
- * @cnc: (allow-none): a #GdaConnection, or %NULL
- * @prov: (allow-none): a #GdaServerProvider, or %NULL
+ * @cnc: a #GdaConnection, or %NULL
+ * @prov: a #GdaServerProvider, or %NULL
  * @path: a complete path to a node (starting with "/")
  *
  * This method is similar to gda_server_operation_get_value_at(), but for SQL identifiers: a new string
@@ -2171,9 +2160,9 @@ gda_server_operation_get_sql_identifier_at_path (GdaServerOperation *op, GdaConn
 /**
  * gda_server_operation_set_value_at_path:
  * @op: a #GdaServerOperation object
- * @value: (allow-none): a string
- * @path: a complete path to a node (starting with "/")
+ * @value: a string
  * @error: a place to store errors or %NULL
+ * @path: a complete path to a node (starting with "/")
  *
  * Set the value for the node at the path formed using @path_format and the ... ellipse (the rules are the same as
  * for g_strdup_printf()). 
@@ -2259,9 +2248,7 @@ gda_server_operation_set_value_at_path (GdaServerOperation *op, const gchar *val
 		switch (opnode->type) {
 		case GDA_SERVER_OPERATION_NODE_PARAMLIST:
 			if (!extension) {
-				g_set_error (error, GDA_SERVER_OPERATION_ERROR,
-					     GDA_SERVER_OPERATION_XML_ERROR,
-					     "%s", 
+				g_set_error (error, 0, 0, "%s", 
 					     _("Parameterlist values can only be set for individual parameters within it"));
 				allok = FALSE;
 			}
@@ -2355,7 +2342,7 @@ gda_server_operation_set_value_at_path (GdaServerOperation *op, const gchar *val
 /**
  * gda_server_operation_set_value_at: (skip)
  * @op: a #GdaServerOperation object
- * @value: (allow-none): a string
+ * @value: a string
  * @error: a place to store errors or %NULL
  * @path_format: a complete path to a node (starting with "/")
  * @...: arguments to use with @path_format to make a complete path
@@ -2417,7 +2404,7 @@ gda_server_operation_set_value_at (GdaServerOperation *op, const gchar *value, G
 /**
  * gda_server_operation_is_valid:
  * @op: a #GdaServerOperation widget
- * @xml_file: (allow-none): an XML specification file (see gda_server_operation_new()) or %NULL
+ * @xml_file: an XML specification file (see gda_server_operation_new())
  * @error: a place to store an error, or %NULL
  *
  * Tells if all the required values in @op have been defined.
@@ -2451,9 +2438,7 @@ gda_server_operation_is_valid (GdaServerOperation *op, const gchar *xml_file, GE
 					value = gda_server_operation_get_value_at (op, path);
 					if (!value) {
 						valid = FALSE;
-						g_set_error (error,
-							     GDA_SERVER_OPERATION_ERROR,
-							     GDA_SERVER_OPERATION_INCORRECT_VALUE_ERROR,
+						g_set_error (error, 0, 0,
 							     _("Missing required value for '%s'"), path);
 						break;
 					}
@@ -2492,7 +2477,7 @@ gda_server_operation_is_valid (GdaServerOperation *op, const gchar *xml_file, GE
 /**
  * gda_server_operation_prepare_create_database:
  * @provider: the database provider to use
- * @db_name: (allow-none): the name of the database to create, or %NULL
+ * @db_name: the name of the database to create, or %NULL
  * @error: a place to store errors, or %NULL
  *
  * Creates a new #GdaServerOperation object which contains the specifications required
@@ -2532,7 +2517,7 @@ gda_server_operation_prepare_create_database (const gchar *provider, const gchar
 
 /**
  * gda_server_operation_perform_create_database:
- * @provider: (allow-none): the database provider to use, or %NULL if @op has been created using gda_server_operation_prepare_create_database()
+ * @provider: the database provider to use, or %NULL if @op has been created using gda_server_operation_prepare_create_database()
  * @op: a #GdaServerOperation object obtained using gda_server_operation_prepare_create_database()
  * @error: a place to store en error, or %NULL
  *
@@ -2565,7 +2550,7 @@ gda_server_operation_perform_create_database (GdaServerOperation *op, const gcha
 /**
  * gda_server_operation_prepare_drop_database:
  * @provider: the database provider to use
- * @db_name: (allow-none): the name of the database to drop, or %NULL
+ * @db_name: the name of the database to drop, or %NULL
  * @error: a place to store errors, or %NULL
  *
  * Creates a new #GdaServerOperation object which contains the specifications required
@@ -2605,7 +2590,7 @@ gda_server_operation_prepare_drop_database (const gchar *provider, const gchar *
 
 /**
  * gda_server_operation_perform_drop_database:
- * @provider: (allow-none): the database provider to use, or %NULL if @op has been created using gda_server_operation_prepare_drop_database()
+ * @provider: the database provider to use, or %NULL if @op has been created using gda_server_operation_prepare_drop_database()
  * @op: a #GdaServerOperation object obtained using gda_server_operation_prepare_drop_database()
  * @error: a place to store en error, or %NULL
  *
@@ -2622,7 +2607,6 @@ gda_server_operation_perform_drop_database (GdaServerOperation *op, const gchar
 	GdaServerProvider *prov;
 
 	g_return_val_if_fail (GDA_IS_SERVER_OPERATION (op), FALSE);
-	g_return_val_if_fail (gda_server_operation_get_op_type (op) == GDA_SERVER_OPERATION_DROP_DB, FALSE);
 	if (provider)
 		prov = gda_config_get_provider (provider, error);
 	else
@@ -2642,7 +2626,7 @@ gda_server_operation_perform_drop_database (GdaServerOperation *op, const gchar
  * @table_name: name of the table to create
  * @error: a place to store errors, or %NULL
  * @...: group of three arguments for column's name, column's #GType
- * and a #GdaEasyCreateTableFlag flag, finished with %NULL
+ * and a #GdaServerOperationCreateTableFlag flag, finished with %NULL
  *
  * Add more arguments if the flag needs them:
  *
@@ -2659,7 +2643,7 @@ gda_server_operation_perform_drop_database (GdaServerOperation *op, const gchar
  * </itemizedlist>
  *
  * Create a #GdaServerOperation object using an opened connection, taking three
- * arguments, a column's name the column's GType and #GdaEasyCreateTableFlag
+ * arguments, a column's name the column's GType and #GdaServerOperationCreateTableFlag
  * flag, you need to finish the list using %NULL.
  *
  * You'll be able to modify the #GdaServerOperation object to add custom options * to the operation. When finished call #gda_server_operation_perform_create_table
