@@ -1,26 +1,20 @@
 /*
- * Copyright (C) 2009 Bas Driessen <bas.driessen@xobas.com>
- * Copyright (C) 2009 Johannes Schmid <jhs@gnome.org>
- * Copyright (C) 2009 - 2010 Murray Cumming <murrayc@murrayc.com>
- * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
- * Copyright (C) 2010 David King <davidk@openismus.com>
- * Copyright (C) 2010 Jonh Wendell <jwendell@gnome.org>
- * Copyright (C) 2011 Daniel Espinosa <esodan@gmail.com>
+ * Copyright (C) 2008 - 2011 Vivien Malerba
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * This Library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful,
+ * This Library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
+ * Library General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA  02110-1301, USA.
+ * You should have received a copy of the GNU Library General Public
+ * License along with this Library; see the file COPYING.LIB.  If not,
+ * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 #include <string.h>
@@ -352,7 +346,7 @@ gda_sql_builder_get_statement (GdaSqlBuilder *builder, GError **error)
 }
 
 /**
- * gda_sql_builder_get_sql_statement: (skip)
+ * gda_sql_builder_get_sql_statement:
  * @builder: a #GdaSqlBuilder object
  *
  * Creates a new #GdaSqlStatement structure from @builder's contents.
@@ -483,8 +477,8 @@ gda_sql_builder_set_where (GdaSqlBuilder *builder, GdaSqlBuilderId cond_id)
  * gda_sql_builder_select_add_field:
  * @builder: a #GdaSqlBuilder object
  * @field_name: a field name
- * @table_name: (allow-none): a table name, or %NULL
- * @alias: (allow-none): an alias (eg. for the "AS" clause), or %NULL
+ * @table_name: a table name, or %NULL
+ * @alias: an alias (eg. for the "AS" clause), or %NULL
  *
  * Valid only for: SELECT statements.
  *
@@ -508,11 +502,8 @@ gda_sql_builder_select_add_field (GdaSqlBuilder *builder, const gchar *field_nam
 	}
 	g_return_val_if_fail (field_name && *field_name, 0);
 
-	gboolean tmp_is_allocated = FALSE;
-	if (table_name && *table_name) {
+	if (table_name && *table_name)
 		tmp = g_strdup_printf ("%s.%s", table_name, field_name);
-		tmp_is_allocated = TRUE;
-	}
 	else
 		tmp = (gchar*) field_name;
 
@@ -525,7 +516,7 @@ gda_sql_builder_select_add_field (GdaSqlBuilder *builder, const gchar *field_nam
 		gda_sql_builder_add_field_value_id (builder,
 						    field_id,
 						    0);
-	if (tmp_is_allocated)
+	if (table_name)
 		g_free (tmp);
 
     return field_id;
@@ -651,7 +642,7 @@ gda_sql_builder_add_field_value (GdaSqlBuilder *builder, const gchar *field_name
  * gda_sql_builder_add_field_value_as_gvalue:
  * @builder: a #GdaSqlBuilder object
  * @field_name: a field name
- * @value: (allow-none): value to set the field to, or %NULL or a GDA_TYPE_NULL value to represent an SQL NULL
+ * @value: value to set the field to, or %NULL or a GDA_TYPE_NULL value to represent an SQL NULL
  *
  * Valid only for: INSERT, UPDATE statements.
  *
@@ -799,8 +790,8 @@ gda_sql_builder_add_field_value_id (GdaSqlBuilder *builder, GdaSqlBuilderId fiel
 /**
  * gda_sql_builder_add_expr_value:
  * @builder: a #GdaSqlBuilder object
- * @dh: (allow-none): a #GdaDataHandler to use, or %NULL
- * @value: (allow-none): value to set the expression to, or %NULL or a GDA_TYPE_NULL value to represent an SQL NULL
+ * @dh: a #GdaDataHandler to use, or %NULL
+ * @value: value to set the expression to, or %NULL or a GDA_TYPE_NULL value to represent an SQL NULL
  *
  * Defines an expression in @builder which may be reused to build other parts of a statement.
  *
@@ -855,7 +846,7 @@ gda_sql_builder_add_expr_value (GdaSqlBuilder *builder, GdaDataHandler *dh, cons
 /**
  * gda_sql_builder_add_expr: (skip)
  * @builder: a #GdaSqlBuilder object
- * @dh: (allow-none): a #GdaDataHandler to use, or %NULL
+ * @dh: a #GdaDataHandler to use, or %NULL
  * @type: the GType of the following argument
  * @...: value to set the expression to, of the type specified by @type
  *
@@ -911,14 +902,14 @@ gda_sql_builder_add_expr (GdaSqlBuilder *builder, GdaDataHandler *dh, GType type
 /**
  * gda_sql_builder_add_id:
  * @builder: a #GdaSqlBuilder object
- * @str: a string
+ * @string: a string
  *
  * Defines an expression representing an identifier in @builder,
  * which may be reused to build other parts of a statement,
  * for instance as a parameter to gda_sql_builder_add_cond() or
  * gda_sql_builder_add_field_value_id().
  *
- * The new expression will contain the @str literal.
+ * The new expression will contain the @string literal.
  * For example:
  * <programlisting>
  * gda_sql_builder_add_id (b, "name")
@@ -940,17 +931,17 @@ gda_sql_builder_add_expr (GdaSqlBuilder *builder, GdaDataHandler *dh, GType type
  * Since: 4.2
  */
 GdaSqlBuilderId
-gda_sql_builder_add_id (GdaSqlBuilder *builder, const gchar *str)
+gda_sql_builder_add_id (GdaSqlBuilder *builder, const gchar *string)
 {
 	g_return_val_if_fail (GDA_IS_SQL_BUILDER (builder), 0);
 	g_return_val_if_fail (builder->priv->main_stmt, 0);
 
 	GdaSqlExpr *expr;
 	expr = gda_sql_expr_new (NULL);
-	if (str) {
+	if (string) {
 		expr->value = gda_value_new (G_TYPE_STRING);
-		g_value_set_string (expr->value, str);
-		expr->value_is_ident = (gpointer) 0x1;
+		g_value_set_string (expr->value, string);
+		expr->value_is_ident = TRUE;
 	}
 
 	return add_part (builder, (GdaSqlAnyPart *) expr);
@@ -979,17 +970,14 @@ GdaSqlBuilderId
 gda_sql_builder_add_field_id (GdaSqlBuilder *builder, const gchar *field_name, const gchar *table_name)
 {
 	gchar* tmp = 0;
-	gboolean tmp_is_allocated = FALSE;
-	if (table_name && *table_name) {
+	if (table_name && *table_name)
 		tmp = g_strdup_printf ("%s.%s", table_name, field_name);
-		tmp_is_allocated = TRUE;
-        }
 	else
 		tmp = (gchar*) field_name;
 
 	guint field_id = gda_sql_builder_add_id (builder, tmp);
 
-	if (tmp_is_allocated)
+	if (table_name)
 		g_free (tmp);
 
 	return field_id;
@@ -1083,7 +1071,7 @@ gda_sql_builder_add_cond (GdaSqlBuilder *builder, GdaSqlOperatorType op, GdaSqlB
 }
 
 /**
- * gda_sql_builder_add_cond_v: (skip)
+ * gda_sql_builder_add_cond_v:
  * @builder: a #GdaSqlBuilder object
  * @op: type of condition
  * @op_ids: (array length=op_ids_size): an array of ID for the arguments (not %0)
@@ -1267,7 +1255,7 @@ typedef struct {
 } BuilderJoin;
 
 /**
- * gda_sql_builder_select_join_targets: (skip)
+ * gda_sql_builder_select_join_targets:
  * @builder: a #GdaSqlBuilder object
  * @left_target_id: the ID of the left target to use (not %0)
  * @right_target_id: the ID of the right target to use (not %0)
@@ -1725,7 +1713,7 @@ gda_sql_builder_add_function_v (GdaSqlBuilder *builder, const gchar *func_name,
 }
 
 /**
- * gda_sql_builder_add_sub_select: (skip)
+ * gda_sql_builder_add_sub_select:
  * @builder: a #GdaSqlBuilder object
  * @sqlst: a pointer to a #GdaSqlStatement, which has to be a SELECT or compound SELECT. This will be copied.
  *
@@ -1788,7 +1776,7 @@ gda_sql_builder_compound_set_type (GdaSqlBuilder *builder, GdaSqlStatementCompou
 }
 
 /**
- * gda_sql_builder_compound_add_sub_select: (skip)
+ * gda_sql_builder_compound_add_sub_select:
  * @builder: a #GdaSqlBuilder object
  * @sqlst: a pointer to a #GdaSqlStatement, which has to be a SELECT or compound SELECT. This will be copied.
  *
@@ -1818,42 +1806,6 @@ gda_sql_builder_compound_add_sub_select (GdaSqlBuilder *builder, GdaSqlStatement
 	cstmt->stmt_list = g_slist_append (cstmt->stmt_list, sub);
 }
 
-
-/**
- * gda_sql_builder_compound_add_sub_select_from_builder:
- * @builder: a #GdaSqlBuilder object
- * @subselect: a #GdaSqlBuilder, which has to be a SELECT or compound SELECT. This will be copied.
- *
- * Add a sub select to a COMPOUND statement
- *
- * Since: 4.2
- */
-void
-gda_sql_builder_compound_add_sub_select_from_builder (GdaSqlBuilder *builder, GdaSqlBuilder *subselect)
-{
-	GdaSqlStatementCompound *cstmt;
-	GdaSqlStatement *sqlst;
-	GdaSqlStatement *sub;
-
-	g_return_if_fail (GDA_IS_SQL_BUILDER (builder));
-	g_return_if_fail (builder->priv->main_stmt);
-	g_return_if_fail (GDA_IS_SQL_BUILDER (subselect));
-	g_return_if_fail (subselect->priv->main_stmt);
-	if (builder->priv->main_stmt->stmt_type != GDA_SQL_STATEMENT_COMPOUND) {
-		g_warning (_("Wrong statement type"));
-		return;
-	}
-	sqlst = gda_sql_builder_get_sql_statement(subselect);
-	g_return_if_fail (sqlst);
-	g_return_if_fail ((sqlst->stmt_type == GDA_SQL_STATEMENT_SELECT) ||
-			  (sqlst->stmt_type == GDA_SQL_STATEMENT_COMPOUND));
-
-	cstmt = (GdaSqlStatementCompound*) builder->priv->main_stmt->contents;
-	sub = gda_sql_statement_copy (sqlst);
-
-	cstmt->stmt_list = g_slist_append (cstmt->stmt_list, sub);
-}
-
 /**
  * gda_sql_builder_add_case: (skip)
  * @builder: a #GdaSqlBuilder object
@@ -1982,7 +1934,7 @@ gda_sql_builder_add_case_v (GdaSqlBuilder *builder,
 }
 
 /**
- * gda_sql_builder_export_expression: (skip)
+ * gda_sql_builder_export_expression:
  * @builder: a #GdaSqlBuilder object
  * @id: the ID of the expression to be exported, (must be a valid ID in @builder, not %0)
  *
@@ -2009,7 +1961,7 @@ gda_sql_builder_export_expression (GdaSqlBuilder *builder, GdaSqlBuilderId id)
 }
 
 /**
- * gda_sql_builder_import_expression: (skip)
+ * gda_sql_builder_import_expression:
  * @builder: a #GdaSqlBuilder object
  * @expr: a #GdaSqlExpr obtained using gda_sql_builder_export_expression()
  *
@@ -2029,33 +1981,3 @@ gda_sql_builder_import_expression (GdaSqlBuilder *builder, GdaSqlExpr *expr)
 	g_return_val_if_fail (GDA_SQL_ANY_PART (expr)->type == GDA_SQL_ANY_EXPR, 0);
 	return add_part (builder, (GdaSqlAnyPart *) gda_sql_expr_copy (expr));
 }
-
-
-/**
- * gda_sql_builder_import_expression_from_builder:
- * @builder: a #GdaSqlBuilder object
- * @query: a #GdaSqlBuilder object to get expression from
- * @expr_id: a #GdaSqlBuilderId of the expression in @query
- *
- * Imports the an expression located in @query into @builder.
- *
- * Returns: the ID of the new expression, or %0 if there was an error
- *
- * Since: 4.2
- */
-GdaSqlBuilderId
-gda_sql_builder_import_expression_from_builder (GdaSqlBuilder *builder, GdaSqlBuilder *query, GdaSqlBuilderId expr_id)
-{
-	GdaSqlExpr *expr;
-	
-	g_return_val_if_fail (GDA_IS_SQL_BUILDER (builder), 0);
-	g_return_val_if_fail (builder->priv->main_stmt, 0);
-	g_return_val_if_fail (GDA_IS_SQL_BUILDER (query), 0);
-	g_return_val_if_fail (query->priv->main_stmt, 0);
-	g_return_val_if_fail (expr_id, 0);
-	
-	expr = gda_sql_builder_export_expression(query, expr_id);
-	g_return_val_if_fail (GDA_SQL_ANY_PART (expr)->type == GDA_SQL_ANY_EXPR, 0);
-	return add_part (builder, (GdaSqlAnyPart *) gda_sql_expr_copy (expr));
-}
-
