@@ -1,22 +1,23 @@
 /*
- * Copyright (C) 2008 Bas Driessen <bas.driessen@xobas.com>
- * Copyright (C) 2008 - 2010 Vivien Malerba <malerba@gnome-db.org>
- * Copyright (C) 2009 - 2010 Murray Cumming <murrayc@murrayc.com>
+ * Copyright (C) 2007 - 2011 The GNOME Foundation.
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * AUTHORS:
+ *      Vivien Malerba <malerba@gnome-db.org>
  *
- * This library is distributed in the hope that it will be useful,
+ * This Library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
+ *
+ * This Library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
+ * Library General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA  02110-1301, USA.
+ * You should have received a copy of the GNU Library General Public
+ * License along with this Library; see the file COPYING.LIB.  If not,
+ * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 #ifndef _GDA_STATEMENT_STRUCT_PARTS_H
@@ -31,75 +32,31 @@
 
 G_BEGIN_DECLS
 
-/*
- * GdaSqlExpr: (skip)
- *
- **/
 typedef struct _GdaSqlExpr      GdaSqlExpr;
-/*
- * GdaSqlField: (skip)
- *
- **/
 typedef struct _GdaSqlField     GdaSqlField;
-/*
- * GdaSqlTable: (skip)
- *
- **/
 typedef struct _GdaSqlTable     GdaSqlTable;
-/*
- * GdaSqlFunction: (skip)
- *
- **/
 typedef struct _GdaSqlFunction  GdaSqlFunction;
-/*
- * GdaSqlOperation: (skip)
- *
- **/
 typedef struct _GdaSqlOperation GdaSqlOperation;
-/*
- * GdaSqlCase: (skip)
- *
- **/
 typedef struct _GdaSqlCase GdaSqlCase;
-/*
- * GdaSqlSelectField: (skip)
- *
- **/
 typedef struct _GdaSqlSelectField GdaSqlSelectField;
-/*
- * GdaSqlSelectTarget: (skip)
- *
- **/
 typedef struct _GdaSqlSelectTarget GdaSqlSelectTarget;
-/*
- * GdaSqlSelectJoin: (skip)
- *
- **/
 typedef struct _GdaSqlSelectJoin GdaSqlSelectJoin;
-/*
- * GdaSqlSelectFrom: (skip)
- *
- **/
 typedef struct _GdaSqlSelectFrom GdaSqlSelectFrom;
-/*
- * GdaSqlSelectOrder: (skip)
- *
- **/
 typedef struct _GdaSqlSelectOrder GdaSqlSelectOrder;
 
 /*
  * Any Expression
  */
 /**
- * GdaSqlExpr: (skip)
+ * GdaSqlExpr:
  * @any: inheritance structure
- * @value: (allow-none): a #GValue, or %NULL. Please see specific note about this field. 
- * @param_spec: (allow-none): a #GdaSqlParamSpec, or %NULL if this is not a variable
- * @func: (allow-none): not %NULL if expression is a function or aggregate
- * @cond: (allow-none): not %NULL if expression is a condition or an operation
- * @select: (allow-none): not %NULL if expression is a sub select statement (#GdaSqlStatementSelect or #GdaSqlStatementCompound)
- * @case_s: (allow-none): not %NULL if expression is a CASE WHEN ... expression
- * @cast_as: (allow-none): not %NULL if expression must be cast to another data type
+ * @value: a #GValue, or %NULL. Please see specific note about this field. 
+ * @param_spec: a #GdaSqlParamSpec, or %NULL if this is not a variable
+ * @func: not %NULL if expression is a function or aggregate
+ * @cond: not %NULL if expression is a condition or an operation
+ * @select: not %NULL if expression is a sub select statement (#GdaSqlStatementSelect or #GdaSqlStatementCompound)
+ * @case_s: not %NULL if expression is a CASE WHEN ... expression
+ * @cast_as: not %NULL if expression must be cast to another data type
  * @value_is_ident: Please see specific note about the @value field
  *
  * This structure contains any expression, either as a value (the @value part is set),
@@ -112,7 +69,7 @@ typedef struct _GdaSqlSelectOrder GdaSqlSelectOrder;
  * <userinput>"'joe'"</userinput> and not <userinput>"joe"</userinput>.
  *
  * Note 2 about the @value field: if the expression represents an SQL identifier (such as a table
- * or field name), then the @value_is_ident should be set to %0x01, and @value should be a string
+ * or field name), then the @value_is_ident should be set to %TRUE, and @value should be a string
  * which may contain double quotes around SQL identifiers which also are reserved keywords or which
  * are case sensitive.
  */
@@ -127,14 +84,14 @@ struct _GdaSqlExpr {
 
 	gchar           *cast_as;
 
-	gpointer         value_is_ident; /* pointer to a boolean to keep ABI from 4.0.
-					  * Non NULL if @value represents an SQL identifier
-					  * Mem in _NOT_ allocated!
-					  */
+	gboolean         value_is_ident;
 
 	/*< private >*/
 	/* Padding for future expansion */
+	gpointer         _gda_reserved1;
 	gpointer         _gda_reserved2;
+	gpointer         _gda_reserved3;
+	gpointer         _gda_reserved4;
 };
 
 #define GDA_TYPE_SQL_EXPR (gda_sql_expr_get_type())
@@ -152,14 +109,13 @@ void             gda_sql_expr_take_select    (GdaSqlExpr *expr, GdaSqlStatement
  * Any Table's field
  */
 /**
- * GdaSqlField: (skip)
+ * GdaSqlField:
  * any: 
  * @field_name: 
  * @validity_meta_table_column: 
  *
  * This structure represents the name of a table's field.
- **/
-
+ */
 struct _GdaSqlField {
 	GdaSqlAnyPart       any;
 	gchar              *field_name;
@@ -185,7 +141,7 @@ void             gda_sql_field_take_name      (GdaSqlField *field, GValue *value
  * Any table
  */
 /**
- * GdaSqlTable: (skip)
+ * GdaSqlTable:
  * @any: 
  * @table_name: 
  * @validity_meta_object: 
@@ -218,13 +174,13 @@ void             gda_sql_table_take_name      (GdaSqlTable *table, GValue *value
  * A function with any number of arguments
  */
 /**
- * GdaSqlFunction: (skip)
+ * GdaSqlFunction:
  * @any: inheritance structure
- * @function_name: name of the function , in the form [[catalog.]schema.]functi
+ * @function_name: name of the function , in the form [[catalog.]schema.]function_name
  * @args_list: list of #GdaSqlExpr expressions, one for each argument
  *
- * This structure represents a function or an aggregate with zero or more argum
- **/
+ * This structure represents a function or an aggregate with zero or more arguments.
+ */
 struct _GdaSqlFunction {
 	GdaSqlAnyPart       any;
 	gchar              *function_name;
@@ -254,8 +210,7 @@ void             gda_sql_function_take_args_list (GdaSqlFunction *function, GSLi
  * @GDA_SQL_OPERATOR_TYPE_OR: 
  * @GDA_SQL_OPERATOR_TYPE_EQ: 
  * @GDA_SQL_OPERATOR_TYPE_IS: 
- * @GDA_SQL_OPERATOR_TYPE_LIKE:
- * @GDA_SQL_OPERATOR_TYPE_ILIKE:  
+ * @GDA_SQL_OPERATOR_TYPE_LIKE: 
  * @GDA_SQL_OPERATOR_TYPE_BETWEEN: 
  * @GDA_SQL_OPERATOR_TYPE_GT: 
  * @GDA_SQL_OPERATOR_TYPE_LT: 
@@ -314,15 +269,14 @@ typedef enum {
 	GDA_SQL_OPERATOR_TYPE_REM,
 	GDA_SQL_OPERATOR_TYPE_BITAND,
 	GDA_SQL_OPERATOR_TYPE_BITOR,
-	GDA_SQL_OPERATOR_TYPE_BITNOT,
-	GDA_SQL_OPERATOR_TYPE_ILIKE
+	GDA_SQL_OPERATOR_TYPE_BITNOT
 } GdaSqlOperatorType;
 
 /**
- * GdaSqlOperation: (skip)
+ * GdaSqlOperation:
  * @any: inheritance structure
  * @operator_type: 
- * @operands: (element-type Gda.SqlExpr): list of #GdaSqlExpr operands
+ * @operands: list of #GdaSqlExpr operands
  *
  * This structure represents an operation between one or more operands.
  */
@@ -348,7 +302,7 @@ GdaSqlOperatorType    gda_sql_operation_operator_from_string (const gchar *op);
  * A CASE expression
  */
 /**
- * GdaSqlCase: (skip)
+ * GdaSqlCase:
  * @any: inheritance structure
  * @base_expr: expression to test
  * @when_expr_list: list of #GdaSqlExpr, one for each WHEN clause
@@ -356,7 +310,7 @@ GdaSqlOperatorType    gda_sql_operation_operator_from_string (const gchar *op);
  * @else_expr: default expression for the CASE
  *
  * This structure represents a CASE WHEN... construct
- **/
+ */
 struct _GdaSqlCase
 {
 	GdaSqlAnyPart    any;
@@ -380,7 +334,7 @@ gchar             *gda_sql_case_serialize      (GdaSqlCase *sc);
  * Any expression in a SELECT ... before the FROM clause
  */
 /**
- * GdaSqlSelectField: (skip)
+ * GdaSqlSelectField:
  * @any: inheritance structure
  * @expr: expression
  * @field_name: field name part of @expr if @expr represents a field
@@ -389,11 +343,11 @@ gchar             *gda_sql_case_serialize      (GdaSqlCase *sc);
  * @validity_meta_object: 
  * @validity_meta_table_column: 
  *
- * This structure represents a selected item in a SELECT statement (when execut
+ * This structure represents a selected item in a SELECT statement (when executed, the returned data set
  * will have one column per selected item). Note that the @table_name and 
- * @field_name field parts <emphasis>will be</emphasis> overwritten by &LIBGDA;
+ * @field_name field parts <emphasis>will be</emphasis> overwritten by &LIBGDA;,
  * set the value of @expr->value instead.
- **/
+ */
 struct _GdaSqlSelectField
 {
 	GdaSqlAnyPart       any;
@@ -426,14 +380,14 @@ void               gda_sql_select_field_take_alias     (GdaSqlSelectField *field
  * Any TARGET ... in a SELECT statement
  */
 /**
- * GdaSqlSelectTarget: (skip)
+ * GdaSqlSelectTarget:
  * @any: inheritance structure
  * @expr: expression
  * @table_name: table name part of @expr if @expr represents a table
  * @as: alias
  * @validity_meta_object: 
  *
- * This structure represents a target used to fetch data from in a SELECT state
+ * This structure represents a target used to fetch data from in a SELECT statement; it can represent a table or
  * a sub select. Note that the @table_name
  * part <emphasis>will be</emphasis> overwritten by &LIBGDA;,
  * set the value of @expr->value instead.
@@ -486,12 +440,12 @@ typedef enum {
 } GdaSqlSelectJoinType;
 
 /**
- * GdaSqlSelectJoin: (skip)
+ * GdaSqlSelectJoin:
  * @any: inheritance structure
  * @type: type of join
  * @position: represents a join between a target at (pos &lt; @position) and the one at @position
- * @expr: (allow-none): joining expression, or %NULL
- * @use: (allow-none): list of #GdaSqlField pointers to use when joining, or %NULL
+ * @expr: joining expression, or %NULL
+ * @use: list of #GdaSqlField pointers to use when joining, or %NULL
  *
  * This structure represents a join between two targets in a SELECT statement.
  */
@@ -521,10 +475,10 @@ const gchar       *gda_sql_select_join_type_to_string (GdaSqlSelectJoinType type
  * Any FROM ... in a SELECT statement
  */
 /**
- * GdaSqlSelectFrom: (skip)
+ * GdaSqlSelectFrom:
  * @any: inheritance structure
- * @targets: (element-type Gda.SqlSelectTarget): list of #GdaSqlSelectTarget
- * @joins: (element-type Gda.SqlSelectJoin): list of #GdaSqlSelectJoin
+ * @targets: list of #GdaSqlSelectTarget
+ * @joins: list of #GdaSqlSelectJoin
  *
  * This structure represents the FROM clause of a SELECT statement, it lists targets and joins
  */
@@ -552,7 +506,7 @@ void               gda_sql_select_from_take_new_join  (GdaSqlSelectFrom *from, G
  * Any expression in a SELECT ... after the ORDER BY
  */
 /**
- * GdaSqlSelectOrder: (skip)
+ * GdaSqlSelectOrder:
  * @any: inheritance structure
  * @expr: expression to order on
  * @asc: TRUE is ordering is ascending
