@@ -1,23 +1,23 @@
-/*
- * Copyright (C) 2008 Murray Cumming <murrayc@murrayc.com>
- * Copyright (C) 2008 - 2010 Vivien Malerba <malerba@gnome-db.org>
- * Copyright (C) 2009 Bas Driessen <bas.driessen@xobas.com>
- * Copyright (C) 2010 David King <davidk@openismus.com>
+/* GDA Jdbc provider
+ * Copyright (C) 2008 - 2010 The GNOME Foundation.
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * AUTHORS:
+ *      Vivien Malerba <malerba@gnome-db.org>
  *
- * This library is distributed in the hope that it will be useful,
+ * This Library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
+ *
+ * This Library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
+ * Library General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA  02110-1301, USA.
+ * You should have received a copy of the GNU Library General Public
+ * License along with this Library; see the file COPYING.LIB.  If not,
+ * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 #include <stdio.h>
@@ -989,7 +989,6 @@ gda_jdbc_provider_get_default_dbms_type (GdaServerProvider *provider, GdaConnect
 	if ((type == G_TYPE_DATE) || 
 	    (type == GDA_TYPE_GEOMETRIC_POINT) ||
 	    (type == G_TYPE_OBJECT) ||
-	    (type == GDA_TYPE_LIST) ||
 	    (type == G_TYPE_STRING) ||
 	    (type == GDA_TYPE_TIME) ||
 	    (type == GDA_TYPE_TIMESTAMP) ||
@@ -1146,7 +1145,7 @@ gda_jdbc_provider_statement_prepare (GdaServerProvider *provider, GdaConnection
 		
 		GValue *jexec_res;
 		jexec_res = jni_wrapper_method_call (jenv, GdaJPStmt__declareParamTypes,
-						     pstmt_obj, NULL, NULL, error, (jlong)GPOINTER_TO_INT(cnc), jtypes);
+						     pstmt_obj, NULL, NULL, error, (jlong) cnc, jtypes);
 		(*jenv)->DeleteLocalRef (jenv, jtypes);
 		g_free (ctypes);
 		
@@ -1318,23 +1317,7 @@ gda_jdbc_provider_statement_execute (GdaServerProvider *provider, GdaConnection
 			}
 		}
 		if (!h) {
-			if (allow_noparam) {
-                                /* bind param to NULL */
-				jexec_res = jni_wrapper_method_call (jenv, GdaJPStmt__setParameterValue,
-								     ps->pstmt_obj, NULL, NULL, &lerror, i, 0);
-				if (!jexec_res) {
-					event = gda_connection_point_available_event (cnc, GDA_CONNECTION_EVENT_ERROR);
-					if (lerror)
-						gda_connection_event_set_description (event,
-						lerror->message ? lerror->message : _("No detail"));
-					g_propagate_error (error, lerror);
-					break;
-				}
-				gda_value_free (jexec_res);
-                                empty_rs = TRUE;
-                                continue;
-			}
-			else {
+			if (! allow_noparam) {
 				gchar *str;
 				str = g_strdup_printf (_("Missing parameter '%s' to execute query"), pname);
 				event = gda_connection_point_available_event (cnc, GDA_CONNECTION_EVENT_ERROR);
@@ -1343,11 +1326,8 @@ gda_jdbc_provider_statement_execute (GdaServerProvider *provider, GdaConnection
 					     GDA_SERVER_PROVIDER_MISSING_PARAM_ERROR, "%s", str);
 				g_free (str);
 				break;
-                        }
-
-		}
-		if (!gda_holder_is_valid (h)) {
-			if (allow_noparam) {
+			}
+			else {
                                 /* bind param to NULL */
 				jexec_res = jni_wrapper_method_call (jenv, GdaJPStmt__setParameterValue,
 								     ps->pstmt_obj, NULL, NULL, &lerror, i, 0);
@@ -1362,8 +1342,11 @@ gda_jdbc_provider_statement_execute (GdaServerProvider *provider, GdaConnection
 				gda_value_free (jexec_res);
                                 empty_rs = TRUE;
                                 continue;
-			}
-			else {
+                        }
+
+		}
+		if (!gda_holder_is_valid (h)) {
+			if (! allow_noparam) {
 				gchar *str;
 				str = g_strdup_printf (_("Parameter '%s' is invalid"), pname);
 				event = gda_connection_point_available_event (cnc, GDA_CONNECTION_EVENT_ERROR);
@@ -1372,6 +1355,22 @@ gda_jdbc_provider_statement_execute (GdaServerProvider *provider, GdaConnection
 					     GDA_SERVER_PROVIDER_MISSING_PARAM_ERROR, "%s", str);
 				g_free (str);
 				break;
+			}
+			else {
+                                /* bind param to NULL */
+				jexec_res = jni_wrapper_method_call (jenv, GdaJPStmt__setParameterValue,
+								     ps->pstmt_obj, NULL, NULL, &lerror, i, 0);
+				if (!jexec_res) {
+					event = gda_connection_point_available_event (cnc, GDA_CONNECTION_EVENT_ERROR);
+					if (lerror)
+						gda_connection_event_set_description (event,
+						lerror->message ? lerror->message : _("No detail"));
+					g_propagate_error (error, lerror);
+					break;
+				}
+				gda_value_free (jexec_res);
+                                empty_rs = TRUE;
+                                continue;
                         }
 		}
 		else if (gda_holder_value_is_default (h) && !gda_holder_get_value (h)) {
@@ -1407,91 +1406,19 @@ gda_jdbc_provider_statement_execute (GdaServerProvider *provider, GdaConnection
 
 		/* actual binding using the C API, for parameter at position @i */
 		const GValue *value = gda_holder_get_value (h);
-		if (!value || gda_value_is_null (value)) {
-			GdaStatement *rstmt;
-			if (! gda_rewrite_statement_for_null_parameters (stmt, params, &rstmt, error)) {
-				jexec_res = jni_wrapper_method_call (jenv, GdaJPStmt__setParameterValue,
-								     ps->pstmt_obj, NULL, NULL, &lerror, i, 
-								     (G_VALUE_TYPE (value) == GDA_TYPE_NULL) ? (glong) 0 : (glong) value);
-				if (!jexec_res) {
-					event = gda_connection_point_available_event (cnc, GDA_CONNECTION_EVENT_ERROR);
-					if (lerror)
-						gda_connection_event_set_description (event,
-										      lerror->message ? lerror->message : _("No detail"));
-					
-					g_propagate_error (error, lerror);
-					break;
-				}
-				gda_value_free (jexec_res);
-			}
-			else if (!rstmt)
-				return NULL;
-			else {
-				_gda_jdbc_release_jenv (jni_detach);
+		jexec_res = jni_wrapper_method_call (jenv, GdaJPStmt__setParameterValue,
+						     ps->pstmt_obj, NULL, NULL, &lerror, i, 
+						     (G_VALUE_TYPE (value) == GDA_TYPE_NULL) ? (glong) 0 : (glong) value);
+		if (!jexec_res) {
+			event = gda_connection_point_available_event (cnc, GDA_CONNECTION_EVENT_ERROR);
+			if (lerror)
+				gda_connection_event_set_description (event,
+								      lerror->message ? lerror->message : _("No detail"));
 
-				/* The strategy here is to execute @rstmt using its prepared
-				 * statement, but with common data from @ps. Beware that
-				 * the @param_ids attribute needs to be retained (i.e. it must not
-				 * be the one copied from @ps) */
-				GObject *obj;
-				GdaJdbcPStmt *tps;
-				GdaPStmt *gtps;
-				GSList *prep_param_ids, *copied_param_ids;
-				if (!gda_jdbc_provider_statement_prepare (provider, cnc,
-									  rstmt, error))
-					return NULL;
-				tps = (GdaJdbcPStmt *)
-					gda_connection_get_prepared_statement (cnc, rstmt);
-				gtps = (GdaPStmt *) tps;
-
-				/* keep @param_ids to avoid being cleared by gda_pstmt_copy_contents() */
-				prep_param_ids = gtps->param_ids;
-				gtps->param_ids = NULL;
-				
-				/* actual copy */
-				gda_pstmt_copy_contents ((GdaPStmt *) ps, (GdaPStmt *) tps);
-
-				/* restore previous @param_ids */
-				copied_param_ids = gtps->param_ids;
-				gtps->param_ids = prep_param_ids;
-
-				/* execute */
-				obj = gda_jdbc_provider_statement_execute (provider, cnc,
-									   rstmt, params,
-									   model_usage,
-									   col_types,
-									   last_inserted_row,
-									   task_id, async_cb,
-									   cb_data, error);
-				/* clear original @param_ids and restore copied one */
-				g_slist_foreach (prep_param_ids, (GFunc) g_free, NULL);
-				g_slist_free (prep_param_ids);
-
-				gtps->param_ids = copied_param_ids;
-
-				/*if (GDA_IS_DATA_MODEL (obj))
-				  gda_data_model_dump ((GdaDataModel*) obj, NULL);*/
-
-				g_object_unref (rstmt);
-				g_object_unref (ps);
-				return obj;
-			}
-		}
-		else {
-			jexec_res = jni_wrapper_method_call (jenv, GdaJPStmt__setParameterValue,
-							     ps->pstmt_obj, NULL, NULL, &lerror, i, 
-							     (G_VALUE_TYPE (value) == GDA_TYPE_NULL) ? (glong) 0 : (glong) value);
-			if (!jexec_res) {
-				event = gda_connection_point_available_event (cnc, GDA_CONNECTION_EVENT_ERROR);
-				if (lerror)
-					gda_connection_event_set_description (event,
-									      lerror->message ? lerror->message : _("No detail"));
-				
-				g_propagate_error (error, lerror);
-				break;
-			}
-			gda_value_free (jexec_res);
+			g_propagate_error (error, lerror);
+			break;
 		}
+		gda_value_free (jexec_res);
 	}
 		
 	if (event) {
@@ -1832,8 +1759,8 @@ gda_jdbc_provider_new (const gchar *jdbc_driver, GError **error)
 	g_return_val_if_fail (jdbc_driver, NULL);
 
 	if (!_jdbc_provider_java_vm) {
-		g_set_error (error, GDA_SERVER_PROVIDER_ERROR, GDA_SERVER_PROVIDER_INTERNAL_ERROR,
-			     "%s", "No JVM runtime identified (this should not happen at this point)!");
+		g_set_error (error, 0, 0, "%s", 
+			     "No JVM runtime identified (this should not happen at this point)!");
 		return NULL;
 	}
 
