@@ -1,29 +1,27 @@
 /*
- * Copyright (C) 2001 - 2003 Rodrigo Moya <rodrigo@gnome-db.org>
- * Copyright (C) 2002 - 2003 Gonzalo Paniagua Javier <gonzalo@gnome-db.org>
- * Copyright (C) 2002 Tim Coleman <tim@timcoleman.com>
- * Copyright (C) 2003 Christian Neumair <cneumair@src.gnome.org>
- * Copyright (C) 2003 Steve Fosdick <fozzy@src.gnome.org>
- * Copyright (C) 2004 Julio M. Merino Vidal <jmmv@menta.net>
- * Copyright (C) 2005 Magnus Bergman <magnus.bergman@observer.net>
- * Copyright (C) 2005 - 2011 Vivien Malerba <malerba@gnome-db.org>
- * Copyright (C) 2006 - 2009 Bas Driessen <bas.driessen@xobas.com>
- * Copyright (C) 2007 Murray Cumming <murrayc@murrayc.com>
+ * Copyright (C) 2009 - 2011 The GNOME Foundation.
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * AUTHORS:
+ *      Rodrigo Moya <rodrigo@gnome-db.org>
+ *      Tim Coleman <tim@timcoleman.com>
+ *      Vivien Malerba <malerba@gnome-db.org>
+ *      Bas Driessen <bas.driessen@xobas.com>
+ *      Andrea Zagli <azagli@libero.it>
  *
- * This library is distributed in the hope that it will be useful,
+ * This Library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
+ *
+ * This Library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
+ * Library General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA  02110-1301, USA.
+ * You should have received a copy of the GNU Library General Public
+ * License along with this Library; see the file COPYING.LIB.  If not,
+ * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 #undef GDA_DISABLE_DEPRECATED
@@ -329,8 +327,7 @@ gda_oracle_provider_get_type (void)
 			NULL, NULL,
 			sizeof (GdaOracleProvider),
 			0,
-			(GInstanceInitFunc) gda_oracle_provider_init,
-			NULL
+			(GInstanceInitFunc) gda_oracle_provider_init
 		};
 		g_static_mutex_lock (&registering);
 		if (type == 0)
@@ -782,7 +779,7 @@ gda_oracle_provider_get_server_version (GdaServerProvider *provider, GdaConnecti
 
 	cdata = (OracleConnectionData*) gda_connection_internal_get_provider_data (cnc);
 	if (!cdata) 
-		return NULL;
+		return FALSE;
 
 	return cdata->version;
 }
@@ -878,8 +875,7 @@ gda_oracle_provider_create_operation (GdaServerProvider *provider, GdaConnection
 	g_free (dir);
 
         if (! file) {
-                g_set_error (error, GDA_SERVER_PROVIDER_ERROR, GDA_SERVER_PROVIDER_FILE_NOT_FOUND_ERROR,
-			     _("Missing spec. file '%s'"), str);
+                g_set_error (error, 0, 0, _("Missing spec. file '%s'"), str);
 		g_free (str);
                 return NULL;
         }
@@ -918,8 +914,7 @@ gda_oracle_provider_render_operation (GdaServerProvider *provider, GdaConnection
 	g_free (dir);
 
         if (! file) {
-                g_set_error (error, GDA_SERVER_PROVIDER_ERROR, GDA_SERVER_PROVIDER_FILE_NOT_FOUND_ERROR,
-			     _("Missing spec. file '%s'"), str);
+                g_set_error (error, 0, 0, _("Missing spec. file '%s'"), str);
 		g_free (str);
                 return NULL;
         }
@@ -1217,7 +1212,6 @@ gda_oracle_provider_get_default_dbms_type (GdaServerProvider *provider, GdaConne
 	if ((type == G_TYPE_DATE) || 
 	    (type == GDA_TYPE_GEOMETRIC_POINT) ||
 	    (type == G_TYPE_OBJECT) ||
-	    (type == GDA_TYPE_LIST) ||
 	    (type == G_TYPE_STRING) ||
 	    (type == GDA_TYPE_TIME) ||
 	    (type == GDA_TYPE_TIMESTAMP) ||
@@ -1289,7 +1283,7 @@ gda_oracle_provider_statement_to_sql (GdaServerProvider *provider, GdaConnection
 	context.flags = flags;
 	context.render_select = (GdaSqlRenderingFunc) oracle_render_select;
 	context.render_select_target = (GdaSqlRenderingFunc) oracle_render_select_target;
-	context.render_expr = oracle_render_expr; /* render "FALSE" as 0 and TRUE as 1 */
+	context.render_expr = oracle_render_expr; /* render "FALSE" as 0 and TRUE as !0 */
 
 	str = gda_statement_to_sql_real (stmt, &context, error);
 
@@ -1313,7 +1307,6 @@ oracle_render_select_target (GdaSqlSelectTarget *target, GdaSqlRenderingContext
 {
         GString *string;
         gchar *str;
-	gpointer tmp;
 
         g_return_val_if_fail (target, NULL);
         g_return_val_if_fail (GDA_SQL_ANY_PART (target)->type == GDA_SQL_ANY_SQL_SELECT_TARGET, NULL);
@@ -1329,8 +1322,9 @@ oracle_render_select_target (GdaSqlSelectTarget *target, GdaSqlRenderingContext
 		g_free (str);
 	}
 	else {
+		gboolean tmp;
 		tmp = target->expr->value_is_ident;
-		target->expr->value_is_ident = (gpointer) 0x1;
+		target->expr->value_is_ident = TRUE;
 		str = context->render_expr (target->expr, context, NULL, NULL, error);
 		target->expr->value_is_ident = tmp;
 		string = g_string_new (str);
@@ -1345,6 +1339,10 @@ oracle_render_select_target (GdaSqlSelectTarget *target, GdaSqlRenderingContext
         str = string->str;
         g_string_free (string, FALSE);
         return str;
+
+ err:
+        g_string_free (string, TRUE);
+        return NULL;
 }
 
 static gchar *
@@ -1466,9 +1464,6 @@ oracle_render_select (GdaSqlStatementSelect *stmt, GdaSqlRenderingContext *conte
 	return NULL;
 }
 
-/*
- * The difference with the default implementation is to render TRUE and FALSE as 0 and 1
- */
 static gchar *
 oracle_render_expr (GdaSqlExpr *expr, GdaSqlRenderingContext *context, 
 		    gboolean *is_default, gboolean *is_null,
@@ -1496,82 +1491,46 @@ oracle_render_expr (GdaSqlExpr *expr, GdaSqlRenderingContext *context,
 		if (!str) goto err;
 	}
 	else if (expr->value) {
-		if (G_VALUE_TYPE (expr->value) == G_TYPE_STRING) {
-			/* specific treatment for strings, see documentation about GdaSqlExpr's value attribute */
-			const gchar *vstr;
-			vstr = g_value_get_string (expr->value);
-			if (vstr) {
-				if (expr->value_is_ident) {
-					gchar **ids_array;
-					gint i;
-					GString *string = NULL;
-					GdaConnectionOptions cncoptions = 0;
-					if (context->cnc)
-						g_object_get (G_OBJECT (context->cnc), "options", &cncoptions, NULL);
-					ids_array = gda_sql_identifier_split (vstr);
-					if (!ids_array)
-						str = g_strdup (vstr);
-					else if (!(ids_array[0])) goto err;
-					else {
-						for (i = 0; ids_array[i]; i++) {
-							gchar *tmp;
-							if (!string)
-								string = g_string_new ("");
-							else
-								g_string_append_c (string, '.');
-							tmp = gda_sql_identifier_quote (ids_array[i], context->cnc,
-											context->provider, FALSE,
-											cncoptions & GDA_CONNECTION_OPTIONS_SQL_IDENTIFIERS_CASE_SENSITIVE);
-							g_string_append (string, tmp);
-							g_free (tmp);
-						}
-						g_strfreev (ids_array);
-						str = g_string_free (string, FALSE);
-					}
-				}
-				else {
-					/* we don't have an identifier */
-					if (!g_ascii_strcasecmp (vstr, "default")) {
-						if (is_default)
-							*is_default = TRUE;
-						str = g_strdup ("DEFAULT");
-					}
-					else if (!g_ascii_strcasecmp (vstr, "FALSE")) {
-						g_free (str);
-						str = g_strdup ("0");
-					}
-					else if (!g_ascii_strcasecmp (vstr, "TRUE")) {
-						g_free (str);
-						str = g_strdup ("1");
-					}
-					else
-						str = g_strdup (vstr);
-				}
-			}
-			else {
-				str = g_strdup ("NULL");
-				if (is_null)
-					*is_null = TRUE;
-			}
-		}
-		if (!str) {
-			/* use a GdaDataHandler to render the value as valid SQL */
-			GdaDataHandler *dh;
-			if (context->cnc) {
-				GdaServerProvider *prov;
-				prov = gda_connection_get_provider (context->cnc);
-				dh = gda_server_provider_get_data_handler_g_type (prov, context->cnc,
-										  G_VALUE_TYPE (expr->value));
-				if (!dh) goto err;
-			}
-			else
-				dh = gda_data_handler_get_default (G_VALUE_TYPE (expr->value));
+		if (expr->value_is_ident && (G_VALUE_TYPE (expr->value) == G_TYPE_STRING)) {
+			gchar **ids_array;
+			gint i;
+			GString *string = NULL;
+			GdaConnectionOptions cncoptions = 0;
+			if (context->cnc)
+				g_object_get (G_OBJECT (context->cnc), "options", &cncoptions, NULL);
 
-			if (dh)
-				str = gda_data_handler_get_sql_from_value (dh, expr->value);
-			else
-				str = gda_value_stringify (expr->value);
+			ids_array = gda_sql_identifier_split (g_value_get_string (expr->value));
+			if ((!ids_array) || !(ids_array[0])) goto err;
+			for (i = 0; ids_array[i]; i++) {
+				gchar *tmp;
+				if (!string)
+					string = g_string_new ("");
+				else
+					g_string_append_c (string, '.');
+				tmp = gda_sql_identifier_quote (ids_array[i], context->cnc, context->provider, FALSE,
+								cncoptions & GDA_CONNECTION_OPTIONS_SQL_IDENTIFIERS_CASE_SENSITIVE);
+				g_string_append (string, tmp);
+				g_free (tmp);
+			}
+			g_strfreev (ids_array);
+			str = g_string_free (string, FALSE);
+		}
+		else {
+			str = gda_value_stringify (expr->value);
 			if (!str) goto err;
+			if (is_null && gda_value_is_null (expr->value))
+				*is_null = TRUE;
+			else if (is_default && (G_VALUE_TYPE (expr->value) == G_TYPE_STRING) && 
+				 !g_ascii_strcasecmp (g_value_get_string (expr->value), "default"))
+				*is_default = TRUE;
+			else if (!g_ascii_strcasecmp (str, "FALSE")) {
+				g_free (str);
+				str = g_strdup ("0");
+			}
+			else if (!g_ascii_strcasecmp (str, "TRUE")) {
+				g_free (str);
+				str = g_strdup ("1");
+			}
 		}
 	}
 	else if (expr->func) {
@@ -1605,7 +1564,10 @@ oracle_render_expr (GdaSqlExpr *expr, GdaSqlRenderingContext *context,
 		str = g_strdup ("NULL");
 	}
 
-	if (!str) goto err;
+	if (!str) {
+		/* TO REMOVE */
+		str = g_strdup ("[...]");
+	}
 
 	if (expr->cast_as) 
 		g_string_append_printf (string, "CAST (%s AS %s)", str, expr->cast_as);
@@ -1863,14 +1825,7 @@ gda_oracle_provider_statement_execute (GdaServerProvider *provider, GdaConnectio
 			}
 		}
 		if (!h) {
-			if (allow_noparam) {
-                                /* bind param to NULL */
-				/* Hint: Indicator Variables, see p. 118 */
-				ora_value = g_new0 (GdaOracleValue, 1);
-				ora_value->indicator = -1;
-                                empty_rs = TRUE;
-			}
-			else {
+			if (! allow_noparam) {
 				gchar *str;
 				str = g_strdup_printf (_("Missing parameter '%s' to execute query"), pname);
 				event = gda_connection_point_available_event (cnc, GDA_CONNECTION_EVENT_ERROR);
@@ -1879,16 +1834,18 @@ gda_oracle_provider_statement_execute (GdaServerProvider *provider, GdaConnectio
 					     GDA_SERVER_PROVIDER_MISSING_PARAM_ERROR, "%s", str);
 				g_free (str);
 				break;
-                        }
-		}
-		else if (!gda_holder_is_valid (h)) {
-			if (allow_noparam) {
+			}
+			else {
                                 /* bind param to NULL */
+				/* Hint: Indicator Variables, see p. 118 */
 				ora_value = g_new0 (GdaOracleValue, 1);
 				ora_value->indicator = -1;
                                 empty_rs = TRUE;
-			}
-			else {
+                        }
+
+		}
+		else if (!gda_holder_is_valid (h)) {
+			if (! allow_noparam) {
 				gchar *str;
 				str = g_strdup_printf (_("Parameter '%s' is invalid"), pname);
 				event = gda_connection_point_available_event (cnc, GDA_CONNECTION_EVENT_ERROR);
@@ -1897,6 +1854,12 @@ gda_oracle_provider_statement_execute (GdaServerProvider *provider, GdaConnectio
 					     GDA_SERVER_PROVIDER_MISSING_PARAM_ERROR, "%s", str);
 				g_free (str);
 				break;
+			}
+			else {
+                                /* bind param to NULL */
+				ora_value = g_new0 (GdaOracleValue, 1);
+				ora_value->indicator = -1;
+                                empty_rs = TRUE;
                         }
 		}
 		else if (gda_holder_value_is_default (h) && !gda_holder_get_value (h)) {
@@ -1930,113 +1893,33 @@ gda_oracle_provider_statement_execute (GdaServerProvider *provider, GdaConnectio
 		}
 
 		/* actual binding using the C API, for parameter at position @i */
-		const GValue *value = gda_holder_get_value (h);
-		if (!ora_value)
+		if (!ora_value) {
+			const GValue *value = gda_holder_get_value (h);
 			ora_value = _gda_value_to_oracle_value (value);
-
-		if (!value || gda_value_is_null (value)) {
-			GdaStatement *rstmt;
-			if (! gda_rewrite_statement_for_null_parameters (stmt, params, &rstmt, error)) {
-				OCIBind *bindpp = (OCIBind *) 0;
-				int result;
-				result = OCIBindByName ((dvoid *) ps->hstmt,
-							(OCIBind **) &bindpp,
-							(OCIError *) cdata->herr,
-							/* param name */
-							(text *) (real_pname ? real_pname : pname),
-							(sb4) strlen (real_pname ? real_pname : pname),
-							/* bound value */
-							(dvoid *) ora_value->value,
-							(sb4) ora_value->defined_size,
-							(ub2) ora_value->sql_type,
-							(dvoid *) &ora_value->indicator,
-							(ub2 *) 0,
-							(ub2) 0,
-							(ub4) 0,
-							(ub4 *) 0,
-							(ub4) OCI_DEFAULT);
-				
-				oravalues_list = g_slist_prepend (oravalues_list, ora_value);
-				if ((event = gda_oracle_check_result (result, cnc, cdata, OCI_HTYPE_ERROR,
-								      _("Could not bind the Oracle statement parameter"))))
-					break;
-			}
-			else if (!rstmt)
-				return NULL;
-			else {
-				/* The strategy here is to execute @rstmt using its prepared
-				 * statement, but with common data from @ps. Beware that
-				 * the @param_ids attribute needs to be retained (i.e. it must not
-				 * be the one copied from @ps) */
-				GObject *obj;
-				GdaOraclePStmt *tps;
-				GdaPStmt *gtps;
-				GSList *prep_param_ids, *copied_param_ids;
-				if (!gda_oracle_provider_statement_prepare (provider, cnc,
-									    rstmt, error))
-					return NULL;
-				tps = (GdaOraclePStmt *)
-					gda_connection_get_prepared_statement (cnc, rstmt);
-				gtps = (GdaPStmt *) tps;
-
-				/* keep @param_ids to avoid being cleared by gda_pstmt_copy_contents() */
-				prep_param_ids = gtps->param_ids;
-				gtps->param_ids = NULL;
-				
-				/* actual copy */
-				gda_pstmt_copy_contents ((GdaPStmt *) ps, (GdaPStmt *) tps);
-
-				/* restore previous @param_ids */
-				copied_param_ids = gtps->param_ids;
-				gtps->param_ids = prep_param_ids;
-
-				/* execute */
-				obj = gda_oracle_provider_statement_execute (provider, cnc,
-									     rstmt, params,
-									     model_usage,
-									     col_types,
-									     last_inserted_row,
-									     task_id, async_cb,
-									     cb_data, error);
-				/* clear original @param_ids and restore copied one */
-				g_slist_foreach (prep_param_ids, (GFunc) g_free, NULL);
-				g_slist_free (prep_param_ids);
-
-				gtps->param_ids = copied_param_ids;
-
-				/*if (GDA_IS_DATA_MODEL (obj))
-				  gda_data_model_dump ((GdaDataModel*) obj, NULL);*/
-
-				g_object_unref (rstmt);
-				g_object_unref (ps);
-				return obj;
-			}
 		}
-		else {
-			OCIBind *bindpp = (OCIBind *) 0;
-			int result;
-			result = OCIBindByName ((dvoid *) ps->hstmt,
-						(OCIBind **) &bindpp,
-						(OCIError *) cdata->herr,
-						/* param name */
-						(text *) (real_pname ? real_pname : pname),
-						(sb4) strlen (real_pname ? real_pname : pname),
-						/* bound value */
-						(dvoid *) ora_value->value,
-						(sb4) ora_value->defined_size,
-						(ub2) ora_value->sql_type,
-						(dvoid *) &ora_value->indicator,
-						(ub2 *) 0,
-						(ub2) 0,
-						(ub4) 0,
-						(ub4 *) 0,
-						(ub4) OCI_DEFAULT);
+		OCIBind *bindpp = (OCIBind *) 0;
+		int result;
+		result = OCIBindByName ((dvoid *) ps->hstmt,
+					(OCIBind **) &bindpp,
+					(OCIError *) cdata->herr,
+					/* param name */
+					(text *) (real_pname ? real_pname : pname),
+					(sb4) strlen (real_pname ? real_pname : pname),
+					/* bound value */
+					(dvoid *) ora_value->value,
+					(sb4) ora_value->defined_size,
+					(ub2) ora_value->sql_type,
+					(dvoid *) &ora_value->indicator,
+					(ub2 *) 0,
+					(ub2) 0,
+					(ub4) 0,
+					(ub4 *) 0,
+					(ub4) OCI_DEFAULT);
 
-			oravalues_list = g_slist_prepend (oravalues_list, ora_value);
-			if ((event = gda_oracle_check_result (result, cnc, cdata, OCI_HTYPE_ERROR,
-							      _("Could not bind the Oracle statement parameter"))))
-				break;
-		}
+		oravalues_list = g_slist_prepend (oravalues_list, ora_value);
+		if ((event = gda_oracle_check_result (result, cnc, cdata, OCI_HTYPE_ERROR,
+						      _("Could not bind the Oracle statement parameter"))))
+			break;
 	}
 		
 	if (event) {
@@ -2522,8 +2405,11 @@ gda_oracle_identifier_quote (GdaServerProvider *provider, GdaConnection *cnc,
         GdaSqlReservedKeywordsFunc kwfunc;
         OracleConnectionData *cdata = NULL;
 
-        if (cnc)
+        if (cnc) {
                 cdata = (OracleConnectionData*) gda_connection_internal_get_provider_data (cnc);
+                if (!cdata)
+                        return NULL;
+        }
 
         kwfunc = _gda_oracle_get_reserved_keyword_func (cdata);
 
@@ -2531,7 +2417,7 @@ gda_oracle_identifier_quote (GdaServerProvider *provider, GdaConnection *cnc,
 		gchar *tmp, *ptr;
 		tmp = ora_remove_quotes (g_strdup (id));
 		if (kwfunc (tmp)) {
-			ptr = gda_sql_identifier_add_quotes (tmp);
+			ptr = gda_sql_identifier_force_quotes (tmp);
 			g_free (tmp);
 			return ptr;
 		}
@@ -2543,7 +2429,7 @@ gda_oracle_identifier_quote (GdaServerProvider *provider, GdaConnection *cnc,
 				    (*ptr == '_'))
 					continue;
 				else {
-					ptr = gda_sql_identifier_add_quotes (tmp);
+					ptr = gda_sql_identifier_force_quotes (tmp);
 					g_free (tmp);
 					return ptr;
 				}
@@ -2562,7 +2448,7 @@ gda_oracle_identifier_quote (GdaServerProvider *provider, GdaConnection *cnc,
 					    (*ptr == '_'))
 						continue;
 					else {
-						ptr = gda_sql_identifier_add_quotes (tmp);
+						ptr = gda_sql_identifier_force_quotes (tmp);
 						g_free (tmp);
 						return ptr;
 					}
@@ -2570,7 +2456,7 @@ gda_oracle_identifier_quote (GdaServerProvider *provider, GdaConnection *cnc,
 				else if ((*ptr >= 'A') && (*ptr <= 'Z'))
 					*ptr += 'a' - 'A';
 				else if ((*ptr >= '0') && (*ptr <= '9') && (ptr == tmp)) {
-					ptr = gda_sql_identifier_add_quotes (tmp);
+					ptr = gda_sql_identifier_force_quotes (tmp);
 					g_free (tmp);
 					return ptr;
 				}
