@@ -1,11 +1,11 @@
-/*
- * Copyright (C) 2009 Vivien Malerba <malerba@gnome-db.org>
- * Copyright (C) 2010 David King <davidk@openismus.com>
+/* browser-canvas-column.c
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
+ * Copyright (C) 2002 - 2010 Vivien Malerba
+ *
+ * This Program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -14,7 +14,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * USA
  */
 
 #include <libgda/libgda.h>
@@ -217,8 +218,8 @@ browser_canvas_column_extra_event  (BrowserCanvasItem *citem, GdkEventType event
 }
 
 /**
- * browser_canvas_column_new: (skip)
- * @parent: (allow-none): the parent item, or %NULL
+ * browser_canvas_column_new
+ * @parent: the parent item, or %NULL
  * @mstruct: the #GdaMetaStruct @column is from
  * @column: the represented entity's column
  * @x: the x coordinate of the text
@@ -232,12 +233,14 @@ browser_canvas_column_new (GooCanvasItem *parent, GdaMetaStruct *mstruct, GdaMet
 			   gdouble x, gdouble y, ...)
 {
 	GooCanvasItem *item;
+	BrowserCanvasColumn *goocolumn;
 	const char *first_property;
 	va_list var_args;
 
 	g_return_val_if_fail (GDA_IS_META_STRUCT (mstruct), NULL);
 
 	item = g_object_new (TYPE_BROWSER_CANVAS_COLUMN, "meta-struct", mstruct, NULL);
+	goocolumn = (BrowserCanvasColumn*) item;
 
 	if (parent) {
 		goo_canvas_item_add_child (parent, item, -1);
@@ -325,10 +328,6 @@ browser_canvas_column_drag_data_get (BrowserCanvasItem *citem, G_GNUC_UNUSED Gdk
 	g_free (tmp2);
 	g_free (tmp3);
 	g_free (tmp4);
-#if GTK_CHECK_VERSION(2,18,0)
 	gtk_selection_data_set (data, gtk_selection_data_get_target (data), 8, (guchar*) str, strlen (str));
-#else
-	gtk_selection_data_set (data, data->target, 8, (guchar*) str, strlen (str));
-#endif
 	g_free (str);
 }
