@@ -1,12 +1,11 @@
-/*
- * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
- * Copyright (C) 2010 David King <davidk@openismus.com>
- * Copyright (C) 2010 Murray Cumming <murrayc@murrayc.com>
+/* browser-canvas.c
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
+ * Copyright (C) 2007 - 2010 Vivien Malerba
+ *
+ * This Program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -15,7 +14,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * USA
  */
 
 #include <glib/gi18n-lib.h>
@@ -25,7 +25,6 @@
 #include "browser-canvas-item.h"
 #include "browser-canvas-print.h"
 #include <libgda/libgda.h>
-#include <libgda-ui/libgda-ui.h>
 
 #define DEFAULT_SCALE .8
 #ifdef HAVE_GRAPHVIZ
@@ -97,9 +96,12 @@ browser_canvas_get_type (void)
 static void
 browser_canvas_class_init (BrowserCanvasClass *klass)
 {
+	GtkWidgetClass *widget_class;
 	GObjectClass   *object_class = G_OBJECT_CLASS (klass);
 	parent_class = g_type_class_peek_parent (klass);
 
+	widget_class = (GtkWidgetClass *) klass;
+
 	/* signals */
 	canvas_signals[ITEM_SELECTED] =
 		g_signal_new ("item-selected",
@@ -168,7 +170,7 @@ browser_canvas_init (BrowserCanvas *canvas)
 		      "automatic-bounds", TRUE,
 		      "bounds-padding", 5., 
 		      "bounds-from-origin", FALSE, 
-		      "anchor", GTK_ANCHOR_CENTER, NULL);
+		      "anchor", GOO_CANVAS_ANCHOR_CENTER, NULL);
 
 	/* reseting the zoom */
 	goo_canvas_set_scale (canvas->priv->goocanvas, DEFAULT_SCALE);
@@ -273,29 +275,17 @@ motion_notify_event_cb (BrowserCanvas *canvas, GdkEvent *event, G_GNUC_UNUSED Go
 				ha = gtk_scrolled_window_get_hadjustment (GTK_SCROLLED_WINDOW (canvas));
 				va = gtk_scrolled_window_get_vadjustment (GTK_SCROLLED_WINDOW (canvas));
 
-#if GTK_CHECK_VERSION(2,18,0)
 				upper = gtk_adjustment_get_upper (ha);
 				lower = gtk_adjustment_get_lower (ha);
 				page_size = gtk_adjustment_get_page_size (ha);
-#else
-				upper = ha->upper;
-				lower = ha->lower;
-				page_size = ha->page_size;
-#endif
 				x = gtk_adjustment_get_value (ha);
 				x = CLAMP (x + canvas->xmouse - ((GdkEventMotion*) event)->x,
 					   lower, upper - page_size);
 				gtk_adjustment_set_value (ha, x);
 
-#if GTK_CHECK_VERSION(2,18,0)
 				upper = gtk_adjustment_get_upper (va);
 				lower = gtk_adjustment_get_lower (va);
 				page_size = gtk_adjustment_get_page_size (va);
-#else
-				upper = va->upper;
-				lower = va->lower;
-				page_size = va->page_size;
-#endif
 				y = gtk_adjustment_get_value (va);
 				y = CLAMP (y + canvas->ymouse - ((GdkEventMotion*) event)->y,
 					   lower, upper - page_size);
@@ -307,13 +297,8 @@ motion_notify_event_cb (BrowserCanvas *canvas, GdkEvent *event, G_GNUC_UNUSED Go
 				canvas->priv->canvas_moving = TRUE;
 				if (! hand_cursor)
 					hand_cursor = gdk_cursor_new (GDK_HAND2);
-#if GTK_CHECK_VERSION(2,18,0)
 				gdk_window_set_cursor (gtk_widget_get_window (GTK_WIDGET (canvas)),
 						       hand_cursor);
-#else
-				gdk_window_set_cursor (GTK_WIDGET (canvas)->window,
-						       hand_cursor);
-#endif
 			}
 		}
 		done = TRUE;
@@ -325,10 +310,8 @@ motion_notify_event_cb (BrowserCanvas *canvas, GdkEvent *event, G_GNUC_UNUSED Go
 	return done;
 }
 
-#ifdef HAVE_GRAPHVIZ
 static void popup_layout_default_cb (GtkMenuItem *mitem, BrowserCanvas *canvas);
 static void popup_layout_radial_cb (GtkMenuItem *mitem, BrowserCanvas *canvas);
-#endif
 static void popup_zoom_in_cb (GtkMenuItem *mitem, BrowserCanvas *canvas);
 static void popup_zoom_out_cb (GtkMenuItem *mitem, BrowserCanvas *canvas);
 static void popup_zoom_fit_cb (GtkMenuItem *mitem, BrowserCanvas *canvas);
@@ -420,11 +403,7 @@ canvas_event_cb (BrowserCanvas *canvas, GdkEvent *event, GooCanvas *gcanvas)
 	case GDK_BUTTON_RELEASE:
 		if (canvas->priv->canvas_moving) {
 			canvas->priv->canvas_moving = FALSE;
-#if GTK_CHECK_VERSION(2,18,0)
 			gdk_window_set_cursor (gtk_widget_get_window (GTK_WIDGET (canvas)), NULL);
-#else
-			gdk_window_set_cursor (GTK_WIDGET (canvas)->window, NULL);
-#endif
 		}
 		break;
 	case GDK_2BUTTON_PRESS:
@@ -456,7 +435,6 @@ canvas_event_cb (BrowserCanvas *canvas, GdkEvent *event, GooCanvas *gcanvas)
 	return done;	
 }
 
-#ifdef HAVE_GRAPHVIZ
 static void
 popup_layout_default_cb (G_GNUC_UNUSED GtkMenuItem *mitem, BrowserCanvas *canvas)
 {
@@ -468,7 +446,6 @@ popup_layout_radial_cb (G_GNUC_UNUSED GtkMenuItem *mitem, BrowserCanvas *canvas)
 {
 	browser_canvas_perform_auto_layout (canvas, TRUE, BROWSER_CANVAS_LAYOUT_RADIAL);
 }
-#endif
 
 static void
 popup_zoom_in_cb (G_GNUC_UNUSED GtkMenuItem *mitem, BrowserCanvas *canvas)
@@ -498,21 +475,14 @@ popup_export_cb (G_GNUC_UNUSED GtkMenuItem *mitem, BrowserCanvas *canvas)
 
 #define MARGIN 5.
 
-#if GTK_CHECK_VERSION(2,18,0)
 	if (!gtk_widget_is_toplevel (toplevel))
 		toplevel = NULL;
-#else
-	if (!GTK_WIDGET_TOPLEVEL (toplevel))
-		toplevel = NULL;
-#endif
 
 	dlg = gtk_file_chooser_dialog_new (_("Save diagram as"), (GtkWindow*) toplevel,
 					   GTK_FILE_CHOOSER_ACTION_SAVE, 
 					   GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 					   GTK_STOCK_SAVE, GTK_RESPONSE_ACCEPT,
 					   NULL);
-	gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (dlg),
-					     gdaui_get_default_path ());
 	filter = gtk_file_filter_new ();
 	gtk_file_filter_set_name (filter, _("PNG Image"));
 	gtk_file_filter_add_mime_type (filter, "image/png");
@@ -529,7 +499,6 @@ popup_export_cb (G_GNUC_UNUSED GtkMenuItem *mitem, BrowserCanvas *canvas)
 		gchar *lcfilename;
 		cairo_surface_t *surface = NULL;
 
-		gdaui_set_default_path (gtk_file_chooser_get_current_folder (GTK_FILE_CHOOSER (dlg)));
 		filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dlg));
 		if (filename) {
 			GooCanvasBounds bounds;
@@ -704,7 +673,8 @@ browser_canvas_set_property (GObject *object,
 			   G_GNUC_UNUSED const GValue *value,
 			   GParamSpec *pspec)
 {
-	BrowserCanvas *canvas;	
+	BrowserCanvas *canvas;
+	
 	canvas = BROWSER_CANVAS (object);
 
 	switch (param_id) {
@@ -788,15 +758,10 @@ browser_canvas_fit_zoom_factor (BrowserCanvas *canvas)
 	g_return_val_if_fail (IS_BROWSER_CANVAS (canvas), 1.);
 	g_return_val_if_fail (canvas->priv, 1.);
 
-#if GTK_CHECK_VERSION(2,18,0)
 	GtkAllocation alloc;
 	gtk_widget_get_allocation (GTK_WIDGET (canvas), &alloc);
 	xall = alloc.width;
 	yall = alloc.height;
-#else
-	xall = GTK_WIDGET (canvas)->allocation.width;
-	yall = GTK_WIDGET (canvas)->allocation.height;
-#endif
 
 	goo_canvas_item_get_bounds (GOO_CANVAS_ITEM (goo_canvas_get_root_item (canvas->priv->goocanvas)),
 				    &bounds);
