@@ -1,20 +1,23 @@
 /*
- * Copyright (C) 2010 David King <davidk@openismus.com>
- * Copyright (C) 2010 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2010 - 2011 The GNOME Foundation.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
+ * AUTHORS:
+ *      Vivien Malerba <malerba@gnome-db.org>
  *
- * This program is distributed in the hope that it will be useful,
+ * This Program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
+ *
+ * This Library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * You should have received a copy of the GNU Library General Public
+ * License along with this Library; see the file COPYING.LIB.  If not,
+ * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 #include <glib/gi18n-lib.h>
@@ -106,7 +109,6 @@ data_widget_init (DataWidget *dwid, G_GNUC_UNUSED DataWidgetClass *klass)
 	gtk_box_pack_start (GTK_BOX (dwid), dwid->priv->top_nb, TRUE, TRUE, 0);
 
 	/* error page */
-#if GTK_CHECK_VERSION (2,18,0)
 	GtkWidget *info;
 	info = gtk_info_bar_new ();
 	gtk_notebook_append_page (GTK_NOTEBOOK (dwid->priv->top_nb), info, NULL);
@@ -115,10 +117,6 @@ data_widget_init (DataWidget *dwid, G_GNUC_UNUSED DataWidgetClass *klass)
 	gtk_label_set_ellipsize (GTK_LABEL (dwid->priv->info_label), PANGO_ELLIPSIZE_END);
 	gtk_container_add (GTK_CONTAINER (gtk_info_bar_get_content_area (GTK_INFO_BAR (info))),
 			   dwid->priv->info_label);
-#else
-	dwid->priv->info_label = gtk_label_new ("");
-	gtk_notebook_append_page (GTK_NOTEBOOK (dwid->priv->top_nb), dwid->priv->info_label, NULL);
-#endif
 
 	/* contents page */
 	GtkWidget *vbox;
@@ -259,12 +257,8 @@ create_or_reuse_part (DataWidget *dwid, DataSource *source, gboolean *out_reused
 
 	part->spinner = BROWSER_SPINNER (browser_spinner_new ());
 	browser_spinner_set_size ((BrowserSpinner*) part->spinner, GTK_ICON_SIZE_LARGE_TOOLBAR);
-#if GTK_CHECK_VERSION(2,20,0)
 	page = gtk_alignment_new (0.5, 0.5, 0., 0.);
 	gtk_container_add (GTK_CONTAINER (page), (GtkWidget*) part->spinner);
-#else
-	page = GTK_WIDGET (part->spinner);
-#endif
 	gtk_notebook_append_page (GTK_NOTEBOOK (nb), page, NULL);
 	part->data_widget = NULL;
 
@@ -645,62 +639,11 @@ source_exec_started_cb (G_GNUC_UNUSED DataSource *source, DataPart *part)
 							     part);
 }
 
-/*
- * creates a new string where double underscores '__' are replaced by a single underscore '_'
- */
-static gchar *
-replace_double_underscores (const gchar *str)
-{
-        gchar **arr;
-        gchar *ret;
-
-        arr = g_strsplit (str, "__", 0);
-        ret = g_strjoinv ("_", arr);
-        g_strfreev (arr);
-
-        return ret;
-}
-
-static void
-customize_form_grid (UiFormGrid *cwid)
-{
-	GdauiRawGrid *grid;
-	grid = ui_formgrid_get_grid_widget (UI_FORMGRID (cwid));
-
-	GList *columns, *list;
-	columns = gtk_tree_view_get_columns (GTK_TREE_VIEW (grid));
-	for (list = columns; list; list = list->next) {
-		/* reduce column's title */
-		const gchar *title;
-		GtkWidget *header;
-		title = gtk_tree_view_column_get_title (GTK_TREE_VIEW_COLUMN (list->data));
-		header = gtk_label_new ("");
-		if (title) {
-			gchar *tmp, *str;
-			str = replace_double_underscores (title);
-			tmp = g_markup_printf_escaped ("<small>%s</small>", str);
-			g_free (str);
-			gtk_label_set_markup (GTK_LABEL (header), tmp);
-			g_free (tmp);
-		}
-		else
-			gtk_label_set_markup (GTK_LABEL (header), "<small></small>");
-		gtk_widget_show (header);
-		gtk_tree_view_column_set_widget (GTK_TREE_VIEW_COLUMN (list->data),
-						 header);
-	}
-	
-	/*if (!columns || !columns->next)*/
-		gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (grid), FALSE);
-	g_list_free (columns);
-}
-
-
-static void formgrid_data_set_changed_cb (UiFormGrid *cwid, DataPart *part);
 static void data_part_selection_changed_cb (GdauiDataSelector *gdauidataselector, DataPart *part);
 static void
 source_exec_finished_cb (G_GNUC_UNUSED DataSource *source, GError *error, DataPart *part)
 {
+	GtkWidget *wid;
 	if (part->spinner_show_timer_id) {
 		g_source_remove (part->spinner_show_timer_id);
 		part->spinner_show_timer_id = 0;
@@ -717,116 +660,75 @@ source_exec_finished_cb (G_GNUC_UNUSED DataSource *source, GError *error, DataPa
 	}
 	
 	if (! part->data_widget) {
-		GtkWidget *cwid, *wid;
+		GtkWidget *cwid;
 		BrowserConnection *bcnc;
 		bcnc = browser_window_get_connection ((BrowserWindow*) gtk_widget_get_toplevel ((GtkWidget*) part->dwid));
 		cwid = (GtkWidget*) data_source_create_grid (part->source);
 		ui_formgrid_handle_user_prefs (UI_FORMGRID (cwid), bcnc,
 					       data_source_get_statement (part->source));
-		g_signal_connect (cwid, "data-set-changed",
-				  G_CALLBACK (formgrid_data_set_changed_cb), part);
 		
 		wid = (GtkWidget*) ui_formgrid_get_grid_widget (UI_FORMGRID (cwid));
 		part->data_widget = wid;
 		part->data_widget_page = gtk_notebook_append_page (part->nb, cwid, NULL);
-		g_signal_connect (part->data_widget, "selection-changed",
-				  G_CALLBACK (data_part_selection_changed_cb), part);
 		gtk_widget_show (cwid);
-
 #ifdef GDA_DEBUG_NO
 		g_print ("Creating data widget for source [%s]\n",
 			 data_source_get_title (part->source));
 #endif
 		
 		/* compute part->export_data */
-		formgrid_data_set_changed_cb (UI_FORMGRID (cwid), part);
-	}
-	else {
-		GError *lerror = NULL;
-		if (! compute_sources_dependencies (part, &lerror)) {
-			data_part_show_error (part, lerror);
-			g_clear_error (&lerror);
+		GArray *export_names;
+		export_names = data_source_get_export_names (part->source);
+		if (export_names && (export_names->len > 0)) {
+			GSList *holders = NULL;
+			GdaDataModel *model;
+			GHashTable *export_columns;
+			gsize i;
+			GdaDataModelIter *iter;
+			
+			iter = gdaui_data_selector_get_data_set (GDAUI_DATA_SELECTOR (wid));
+			g_object_get (wid, "model", &model, NULL);
+			
+			export_columns = data_source_get_export_columns (part->source);
+			for (i = 0; i < export_names->len; i++) {
+				gint col;
+				GdaHolder *bindto;
+				col = GPOINTER_TO_INT (g_hash_table_lookup (export_columns,
+									    g_array_index (export_names,
+											   gchar*, i))) - 1;
+				bindto = gda_data_model_iter_get_holder_for_field (iter, col);
+				if (bindto) {
+					GdaHolder *holder;
+					holder = gda_holder_copy (bindto);
+					g_object_set ((GObject*) holder, "id",
+						      g_array_index (export_names, gchar*, i), NULL);
+					holders = g_slist_prepend (holders, holder);
+#ifdef DEBUG_NO
+					g_print ("HOLDER [%s::%s]\n",
+						 gda_holder_get_id (holder),
+						 g_type_name (gda_holder_get_g_type (holder)));
+#endif
+					g_assert (gda_holder_set_bind (holder, bindto, NULL));
+				}
+			}
+			
+			g_object_unref (model);
+			if (holders) {
+				part->export_data = gda_set_new (holders);
+				g_slist_foreach (holders, (GFunc) g_object_unref, NULL);
+				g_slist_free (holders);
+				
+				g_signal_connect (wid, "selection-changed",
+						  G_CALLBACK (data_part_selection_changed_cb), part);
+			}
 		}
 	}
 	gtk_notebook_set_current_page (part->nb, part->data_widget_page);
-}
-
-static void
-formgrid_data_set_changed_cb (UiFormGrid *cwid, DataPart *part)
-{
-	GtkWidget *wid;
-	GArray *export_names;
-
-	customize_form_grid (cwid);
-	wid = (GtkWidget*) ui_formgrid_get_grid_widget (UI_FORMGRID (cwid));
-
-	if (part->export_data) {
-		g_object_unref (part->export_data);
-		part->export_data = NULL;
-	}
-
-#ifdef GDA_DEBUG_NO
-	g_print ("+++++ Reset export_data for data source [%s]\n", data_source_get_id (part->source));
-#endif	
-
-	export_names = data_source_get_export_names (part->source);
-	if (export_names && (export_names->len > 0)) {
-		GSList *holders = NULL;
-		GdaDataModel *model;
-		GHashTable *export_columns;
-		gsize i;
-		GdaDataModelIter *iter;
-		
-		iter = gdaui_data_selector_get_data_set (GDAUI_DATA_SELECTOR (wid));
-		g_object_get (wid, "model", &model, NULL);
-		
-		export_columns = data_source_get_export_columns (part->source);
-		for (i = 0; i < export_names->len; i++) {
-			gint col;
-			GdaHolder *bindto;
-			col = GPOINTER_TO_INT (g_hash_table_lookup (export_columns,
-								    g_array_index (export_names,
-										   gchar*, i))) - 1;
-			bindto = gda_data_model_iter_get_holder_for_field (iter, col);
-			if (bindto) {
-				GdaHolder *holder;
-				holder = gda_holder_copy (bindto);
-				g_object_set ((GObject*) holder, "id",
-					      g_array_index (export_names, gchar*, i), NULL);
-				holders = g_slist_prepend (holders, holder);
-#ifdef GDA_DEBUG_NO
-				g_print ("HOLDER [%s::%s]\n",
-					 gda_holder_get_id (holder),
-					 g_type_name (gda_holder_get_g_type (holder)));
-#endif
-				g_assert (gda_holder_set_bind (holder, bindto, NULL));
-			}
-		}
-		
-		g_object_unref (model);
-		if (holders) {
-			part->export_data = gda_set_new (holders);
-			g_slist_foreach (holders, (GFunc) g_object_unref, NULL);
-			g_slist_free (holders);
-		}
-	}
 
 	GError *lerror = NULL;
 	if (! compute_sources_dependencies (part, &lerror)) {
 		data_part_show_error (part, lerror);
 		g_clear_error (&lerror);
-		lerror = NULL;
-	}
-
-	if (part->dep_parts) {
-		GSList *list;
-		for (list = part->dep_parts; list; list = list->next) {
-			if (! compute_sources_dependencies ((DataPart*) list->data, &lerror)) {
-				data_part_show_error (part, lerror);
-				g_clear_error (&lerror);
-				lerror = NULL;
-			}
-		}
 	}
 }
 
@@ -835,13 +737,11 @@ data_part_selection_changed_cb (G_GNUC_UNUSED GdauiDataSelector *gdauidataselect
 {
 	if (part->export_data) {
 		GSList *list;
-#ifdef GDA_DEBUG_NO
+#ifdef DEBUG_NO
 		for (list = part->export_data->holders; list; list = list->next) {
 			GdaHolder *holder = GDA_HOLDER (list->data);
 			gchar *tmp;
 			tmp = gda_value_stringify (gda_holder_get_value (holder));
-			if (strlen (tmp) > 10)
-				tmp [15] = 0;
 			g_print ("%s=>[%s]\n", gda_holder_get_id (holder), tmp);
 			g_free (tmp);
 		}
@@ -877,7 +777,6 @@ compute_sources_dependencies (DataPart *part, GError **error)
 
 			GdaSet *export;
 			GdaHolder *holder2;
-			opart->dep_parts = g_slist_remove (opart->dep_parts, part);
 			export = data_widget_get_export (part->dwid, opart->source);
 			if (!export)
 				continue;
@@ -907,15 +806,15 @@ compute_sources_dependencies (DataPart *part, GError **error)
 						g_clear_error (&lerror);
 				}
 #ifdef GDA_DEBUG_NO
-				else {
-					g_print ("[%s].[%s] bound to [%s].[%s]\n",
-						 data_source_get_id (part->source),
-						 hid,
-						 data_source_get_id (opart->source),
-						 gda_holder_get_id (holder2));
-				}
+				g_print ("[%s.][%s] bound to [%s].[%s]\n",
+					 data_source_get_title (part->source),
+					 hid,
+					 data_source_get_title (opart->source),
+					 gda_holder_get_id (holder2));
 #endif
-				opart->dep_parts = g_slist_append (opart->dep_parts, part);
+				
+				if (! g_slist_find (opart->dep_parts, part))
+					opart->dep_parts = g_slist_append (opart->dep_parts, part);
 				continue;
 			}
 		}
