@@ -1,20 +1,23 @@
-/*
- * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
- * Copyright (C) 2010 David King <davidk@openismus.com>
+/* 
+ * Copyright (C) 2009 - 2011 The GNOME Foundation.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
+ * AUTHORS:
+ *      Vivien Malerba <malerba@gnome-db.org>
  *
- * This program is distributed in the hope that it will be useful,
+ * This Program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
+ *
+ * This Library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * You should have received a copy of the GNU Library General Public
+ * License along with this Library; see the file COPYING.LIB.  If not,
+ * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 #include <glib/gi18n-lib.h>
@@ -201,7 +204,7 @@ browser_show_message (GtkWindow *parent, const gchar *format, ...)
 #ifdef HAVE_GDU
 /**
  * browser_show_help
- * @topic: (allow-none): the help topic, or %NULL for the global index
+ * @topic: the help topic, or %NULL for the global index
  */
 void
 browser_show_help (GtkWindow *parent, const gchar *topic)
@@ -247,7 +250,6 @@ browser_show_help (GtkWindow *parent, const gchar *topic)
 		return;
 	}
 
-#if GTK_CHECK_VERSION(2,14,0)
 	gchar *ruri;
 
 	screen = gtk_widget_get_screen ((GtkWidget*) parent);
@@ -255,14 +257,6 @@ browser_show_help (GtkWindow *parent, const gchar *topic)
 	gtk_show_uri (screen, ruri,  gtk_get_current_event_time (), &error);
 	g_free (ruri);
 
-#else
-	gchar *command;
-	
-	command = g_strconcat ("gnome-help ghelp://", uri,  NULL);
-	screen = gtk_widget_get_screen (GTK_WIDGET (parent));
-	gdk_spawn_command_line_on_screen (screen, command, &error);
-	g_free (command);
-#endif
 	if (error) {
 		GtkWidget *d;
 		d = gtk_message_dialog_new (parent, 
@@ -390,6 +384,8 @@ browser_get_pixbuf_icon (BrowserIconType type)
 		"gda-browser-diagram.png",
 		"gda-browser-query.png",
 		"gda-browser-action.png",
+		"gda-browser-grid.png",
+		"gda-browser-form.png",
 		"gda-browser-menu-ind.png",
 		"gda-browser-ldap-entry.png",
 		"gda-browser-ldap-group.png",
